@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_users.pl,v 1.36 2004/06/26 10:04:14 yeupou Exp $
+# $Id: sv_users.pl,v 1.37 2004/09/22 08:11:50 yeupou Exp $
 #
 #  Copyright 2001      (c) Loic Dachary <loic--at--gnu.org> (sv_cvs.pl)
 #            2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
@@ -57,6 +57,7 @@ my $getopt;
 my $help;
 my $debug;
 my $cron;
+my $version = GetVersion();
 
 my $useradd = "useradd";
 my $usermod = "usermod";
@@ -101,11 +102,11 @@ Note that users are associated with the group svusers.
 
       --userx-prefix=[prefix]  Specify a prefix for user* bin
                                For instance, for useradd.
-      --useradd=[useradd]      Speficy useradd binary
-      --usermod=[usermod]      Speficy usermod binary
-      --userdel=[userdel]      Speficy userdel binary
-  
-Authors: Loic Dachary <loic\@gnu.org>, Mathieu Roy <yeupou\@gnu.org>
+      --useradd=[useradd]      Specify useradd binary
+      --usermod=[usermod]      Specify usermod binary
+      --userdel=[userdel]      Specify userdel binary
+
+Savane version: $version
 EOF
 exit(1);
 }
@@ -159,12 +160,12 @@ my %db_user;
 my @db_users;
 foreach my $line (GetDB("user", 
 			"status='A' OR status='D'",
-			"user_name,email,realname,authorized_keys,gpg_key,status,unix_status, use_cvsadmin")) {
+			"user_name,email,realname,authorized_keys,gpg_key,status")) {
     chomp($line);
-    my ($user, $email, $realname, $authorized_keys, $gpg_keys, $status, $unix_status, $use_cvsadmin) = split(",", $line);
+    my ($user, $email, $realname, $authorized_keys, $gpg_keys, $status) = split(",", $line);
     print "DBG db: get $user <$email> from database\n" if $debug;
     $realname =~ s/\://g;
-    $db_user{$user} = [ ($user, $email, $realname, $authorized_keys, $gpg_keys, $status, $unix_status, $use_cvsadmin) ];
+    $db_user{$user} = [ ($user, $email, $realname, $authorized_keys, $gpg_keys, $status) ];
     push (@db_users, $user);
 }
 
@@ -365,7 +366,7 @@ foreach my $user (@only_in_db){
     # We only create an account for project's members
     if (exists($db_user_group{$user})) {
 	
-	my ($user_name, $email, $realname, $authorized_keys, $gpg_keys, $status, $unix_status, $use_cvsadmin) = @{$db_user{$user}};
+	my ($user_name, $email, $realname, $authorized_keys, $gpg_keys, $status) = @{$db_user{$user}};
 	my $home = GetUserHome($user);
 	my $groups = join ",", @{$db_user_group{$user}};
 	my $ssh_keys_count = 0;
@@ -450,9 +451,7 @@ foreach my $user (@well_known) {
 	$realname,
 	$authorized_keys,
 	$gpg_keys,
-	$status,
-	$unix_status,
-	$use_cvsadmin) = @{$db_user{$user}};
+	$status) = @{$db_user{$user}};
 
 
     # Update groups: check if the system knows all groups the user
