@@ -1,30 +1,25 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: group_type.php,v 1.25 2004/03/06 12:31:07 toddy Exp $
-//
-//
-//
-//  Copyright (C) 2002-2003 Mathieu Roy <yeupou@gnu.org>
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: group_type.php,v 1.26 2004/09/22 08:11:50 yeupou Exp $
+#
+#  Copyright (C) 2002-2004 Mathieu Roy <yeupou--at--gnu.org>
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 
 require "../include/pre.php";
 require  $GLOBALS['sys_urlroot']."/include/vars.php";
@@ -32,7 +27,7 @@ require_directory("project");
 
 session_require(array('group'=>'1','admin_flags'=>'A'));
 
-// group public choice
+# group public choice
 if ($delete)
 {
   $result = db_query("DELETE FROM group_type WHERE type_id='$form_type_id'");
@@ -104,7 +99,8 @@ if ($update) {
 		     . "is_menu_configurable_cvs_viewcvs_homepage='$form_is_menu_configurable_cvs_viewcvs_homepage',"
 		     . "is_menu_configurable_bugs='$form_is_menu_configurable_bugs',"
 		     . "is_menu_configurable_task='$form_is_menu_configurable_task',"
-		     . "is_menu_configurable_patch='$form_is_menu_configurable_patch'"
+		     . "is_menu_configurable_patch='$form_is_menu_configurable_patch',"
+		     . "is_configurable_download_dir='$form_is_menu_configurable_download_dir'"
 		     . " WHERE "
 		     . "type_id='$form_type_id'");
 
@@ -133,6 +129,28 @@ if ($update) {
     { fb(sprintf(_("Unable to update group type user permissions settings: %s"), db_error()),0); }
   else
     { fb(_("group type user permissions settings updated")); }
+
+  $bugs_flags="bugs_restrict";
+  $task_flags="task_restrict";
+  $patch_flags="patch_restrict";
+  $support_flags="support_restrict";
+  $news_flags="news_restrict";
+
+  $sql = 'UPDATE group_type SET '
+     ."bugs_rflags=".$$bugs_flags.","
+     ."news_rflags=".$$news_flags.","
+     ."task_rflags=".$$task_flags.", "
+     ."patch_rflags=".$$patch_flags.", "
+     ."support_rflags=".$$support_flags." "
+     ."WHERE type_id='$form_type_id'";
+
+  $result = db_query($sql);
+
+  if (!$result)
+    { fb(sprintf(_("Unable to update group type posting restrictions settings: %s"), db_error()),0); }
+  else
+    { fb(_("group type posting restrictions settings updated")); }
+
 }
 
 
@@ -144,7 +162,7 @@ if (!isset($type_id))
 
   while ($usr = db_fetch_array($result))
     {
-      print '<a href="'.$PHP_SELF.'?type_id='.$usr[type_id].'">Type #'.$usr[type_id].': '.$usr[name].'</a><br>';
+      print '<a href="'.$PHP_SELF.'?type_id='.$usr[type_id].'">Type #'.$usr[type_id].': '.$usr[name].'</a><br />';
       $last=$usr[type_id];
     }
   $type=$last+1;
@@ -175,18 +193,18 @@ else
   print '<FORM action="'.$PHP_SELF.'" method="POST">
 <INPUT type="hidden" name="form_type_id" value="'.$type_id.'">';
 
-  // ####################################################################
-  // GENERAL SETTINGS
-  // ####################################################################
+  # ####################################################################
+  # GENERAL SETTINGS
+  # ####################################################################
 
   $HTML->box1_top(_("General Default Settings for Groups of this Type"));
 
   $textfield_size='65';
 
-  // ########### Help
+  # ########### Help
 
   print '
-<p>Basic Help: host means hostname (as savannah.gnu.org), dir means directory (as /usr/local/savannah), url means -well- url (as http://savannah.gnu.org/blah ).
+<p>Basic Help: host means hostname (as savannah.gnu.org), dir means directory (as /usr/local/savannah), url means -well- url (as http:#savannah.gnu.org/blah ).
 
 <p class="warn">Everytime a project\'s unix_group_name should appear, use the special string %PROJECT.
 
@@ -196,111 +214,106 @@ else
 
 </td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 <h3>General information:</h3>
-Name:<br>
+Name:<br />
 <input type="text" name="form_name" value="'.$row_grp['name'].'" size="'.$textfield_size.'">
-<br>Base Host:<br>
+<br />Base Host:<br />
 <input type="text" name="form_base_host" value="'.$row_grp['base_host'].'" size="'.$textfield_size.'">
-<br>Description (will be added on each project homepage):<br>
+<br />Description (will be added on each project homepage):<br />
 <textarea cols="'.$textfield_size.'" rows="6"wrap="virtual" name="form_description">'.$row_grp['description'].'</textarea>
-<br>Admin Email Address:<br>
+<br />Admin Email Address:<br />
 <input type="text" name="form_admin_email_adress" value="'.$row_grp['admin_email_adress'].'" size="'.$textfield_size.'">
 
 ';
   $i++;
 
-  // ########### Homepage
+  # ########### Homepage
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Homepage:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_homepage" VALUE="1"'.( ($row_grp['can_use_homepage']==1) ? ' CHECKED' : '' ).'> can use homepage.<br>';
-
-  // USELESS
-  //<br>Do we guess homepage directory: <INPUT TYPE="CHECKBOX" NAME="form_is_dir_homepage_guessed" VALUE="1"'.( ($row_grp['is_dir_homepage_guessed']==1) ? ' CHECKED' : '' ).'>';
-  // <br><i>(by appending the group_name - deselect if you want projects having a homepage directory with a different name than their group_name)</i><br>';
-
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_homepage" VALUE="1"'.( ($row_grp['can_use_homepage']==1) ? ' checked="checked"' : '' ).'> can use homepage.<br />';
   html_select_typedir_box("form_dir_type_homepage",
 			  $row_grp['dir_type_homepage']);
 
   print '
-<br>Homepage Dir (path on the filesystem) [BACKEND SPECIFIC]:<br>
+<br />Homepage Dir (path on the filesystem) [BACKEND SPECIFIC]:<br />
 <input type="text" name="form_dir_homepage" value="'.$row_grp['dir_homepage'].'" size="'.$textfield_size.'">';
   print '
-<br><br>Homepage URL:<br>
+<br /><br />Homepage URL:<br />
 <input type="text" name="form_url_homepage" value="'.$row_grp['url_homepage'].'" size="'.$textfield_size.'">';
-  //<br>Homepage CVS module prefix (at sv.gnu.org, it would be non-gnu/%PROJECT):<br>
-  //<input type="text" name="form_homepage_cvs_module_prefix" value="'.$row_grp['homepage_cvs_module_prefix'].'" size="'.$textfield_size.'">
+
   print '
-<br><br>Homepage CVS view url (webcvs, viewcvs):<br>
+<br /><br />Homepage CVS view url (webcvs, viewcvs):<br />
 <input type="text" name="form_url_cvs_viewcvs_homepage" value="'.$row_grp['url_cvs_viewcvs_homepage'].'" size="'.$textfield_size.'">
 
 ';
   $i++;
 
-  // ########### Source code
+  # ########### Source code
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Source Code (CVS):</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_cvs" VALUE="1"'.( ($row_grp['can_use_cvs']==1) ? ' CHECKED' : '' ).'> can use CVS<br>';
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_cvs" VALUE="1"'.( ($row_grp['can_use_cvs']==1) ? ' checked="checked"' : '' ).'> can use CVS<br />';
 
   html_select_typedir_box("form_dir_type_cvs",
 			  $row_grp['dir_type_cvs']);
 
-print '<br>CVS Dir (path on the filesystem) [BACKEND SPECIFIC]:<br>
+print '<br />CVS Dir (path on the filesystem) [BACKEND SPECIFIC]:<br />
 <input type="text" name="form_dir_cvs" value="'.$row_grp['dir_cvs'].'" size="'.$textfield_size.'">
-<br><br>CVS view url (webcvs, viewcvs):<br>
+<br /><br />CVS view url (webcvs, viewcvs):<br />
 <input type="text" name="form_url_cvs_viewcvs" value="'.$row_grp['url_cvs_viewcvs'].'" size="'.$textfield_size.'">
 ';
   $i++;
 
-  // ########### License
+  # ########### License
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>License:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_license" VALUE="1"'.( ($row_grp['can_use_license']==1) ? ' CHECKED' : '' ).'> can use license
-<br><br>License list (short name, update include/vars.php for name and url association):<br>
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_license" VALUE="1"'.( ($row_grp['can_use_license']==1) ? ' checked="checked"' : '' ).'> can use license
+<br /><br />License list (short name, update include/vars.php for name and url association):<br />
 <TEXTAREA cols="'.$textfield_size.'" rows="6"wrap="virtual" name="form_license_array">'.$row_grp['license_array'].'</textarea>
 
 ';
   $i++;
 
-  // ########### Devel status
+  # ########### Devel status
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Devel Status:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_devel_status" VALUE="1"'.( ($row_grp['can_use_license']==1) ? ' CHECKED' : '' ).'> can use devel status
-<br>
-<br>Devel Status list:<br>
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_devel_status" VALUE="1"'.( ($row_grp['can_use_license']==1) ? ' checked="checked"' : '' ).'> can use devel status
+<br />
+<br />Devel Status list:<br />
 <TEXTAREA cols="'.$textfield_size.'" rows="6" wrap="virtual" name="form_devel_status_array">'.$row_grp['devel_status_array'].'</textarea>
 
 
 ';
   $i++;
 
-  // ########### Download
+  # ########### Download
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Download Area:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_download" VALUE="1"'.( ($row_grp['can_use_download']==1) ? ' CHECKED' : '' ).'>
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_download" VALUE="1"'.( ($row_grp['can_use_download']==1) ? ' checked="checked"' : '' ).'>
 can use download area.
-<br>';
+<br />
+';
 
   html_select_typedir_box("form_dir_type_download",
 			  $row_grp['dir_type_download']);
 
-  print '<br>Download Dir (path on the filesystem) [BACKEND SPECIFIC]:<br>
+  print '<br />Download Dir (path on the filesystem) [BACKEND SPECIFIC + filelist]:<br />
 <input type="text" name="form_dir_download" value="'.$row_grp['dir_download'].'" size="'.$textfield_size.'">
-<br><br>Download Url:<br>
+<br /><br />Download Url:<br />
 <input type="text" name="form_url_download" value="'.$row_grp['url_download'].'" size="'.$textfield_size.'">
 
 ';
   $i++;
 
-  // ###########  Mailing List
+  # ###########  Mailing List
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
@@ -308,100 +321,100 @@ can use download area.
 
 <font class="warn">Help: Everytime a mailing-list name should appear, use the special string %LIST. Note that if you do not want the Savannah software to interact with your mail host (for instance to truly create mailing list), do not fill the mail host information.</font>
 
-<br>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_mailing_list" VALUE="1"'.( ($row_grp['can_use_mailing_list']==1) ? ' CHECKED' : '' ).'>
-Can use mailing-list.<br>
-<br>Mailing List Host:<br>
+<br />
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_mailing_list" VALUE="1"'.( ($row_grp['can_use_mailing_list']==1) ? ' checked="checked"' : '' ).'>
+Can use mailing-list.<br />
+<br />Mailing List Host:<br />
 <input type="text" name="form_mailing_list_host" value="'.$row_grp['mailing_list_host'].'" size="'.$textfield_size.'">
 
-<br><br>Mailing list address (would be %LIST@gnu.org for GNU projects at sv.gnu.org):<br>
+<br /><br />Mailing list address (would be %LIST@gnu.org for GNU projects at sv.gnu.org):<br />
 <input type="text" name="form_mailing_list_address" value="'.$row_grp['mailing_list_address'].'" size="'.$textfield_size.'">
 
-<br><br>
+<br /><br />
 
-<br>Mailing list name format:<br>
-You can force projects to follow a specific policy for the name of the %LIST. Here you should use the special wildcard %NAME, which is the part the of the mailing list name that the project admin can define (would be %PROJECT-%NAME for non-GNU projects at sv.gnu.org).<br><font class="warn">Do no add any @hostname here!</font><br>
+<br />Mailing list name format:<br />
+You can force projects to follow a specific policy for the name of the %LIST. Here you should use the special wildcard %NAME, which is the part the of the mailing list name that the project admin can define (would be %PROJECT-%NAME for non-GNU projects at sv.gnu.org).<br /><font class="warn">Do no add any @hostname here!</font><br />
 <input type="text" name="form_mailing_list_format" value="'.$row_grp['mailing_list_format'].'" size="'.$textfield_size.'">
 
-<br><br>
+<br /><br />
 
-<br>Listinfo Url:<br>
+<br />Listinfo Url:<br />
 <input type="text" name="form_url_mailing_list_listinfo" value="'.$row_grp['url_mailing_list_listinfo'].'" size="'.$textfield_size.'">
 
-<br><br>Subscribe Url (for majordomo at CERN, it is majordomo_interface.php?func=subscribe&amp;list=%LIST&amp;mailserver=listbox.server@cern.ch):<br>
+<br /><br />Subscribe Url (for majordomo at CERN, it is majordomo_interface.php?func=subscribe&amp;list=%LIST&amp;mailserver=listbox.server@cern.ch):<br />
 <input type="text" name="form_url_mailing_list_subscribe" value="'.$row_grp['url_mailing_list_subscribe'].'" size="'.$textfield_size.'">
 
-<br><br>Unsubscribe Url (for majordomo at CERN, it is majordomo_interface.php?func=subscribe&amp;list=%LIST&amp;mailserver=listbox.server@cern.ch):<br>
+<br /><br />Unsubscribe Url (for majordomo at CERN, it is majordomo_interface.php?func=subscribe&amp;list=%LIST&amp;mailserver=listbox.server@cern.ch):<br />
 <input type="text" name="form_url_mailing_list_unsubscribe" value="'.$row_grp['url_mailing_list_unsubscribe'].'" size="'.$textfield_size.'">
 
-<br><br>Archives URl:<br>
+<br /><br />Archives URl:<br />
 <input type="text" name="form_url_mailing_list_archives" value="'.$row_grp['url_mailing_list_archives'].'" size="'.$textfield_size.'">
 
-<br><br>Private Archives URl:<br>
+<br /><br />Private Archives URl:<br />
 <input type="text" name="form_url_mailing_list_archives_private" value="'.$row_grp['url_mailing_list_archives_private'].'" size="'.$textfield_size.'">
 
-<br><br>Administrative Interface Url:<br>
+<br /><br />Administrative Interface Url:<br />
 <input type="text" name="form_url_mailing_list_admin" value="'.$row_grp['url_mailing_list_admin'].'" size="'.$textfield_size.'">
 
 ';
   $i++;
 
-  // ########### Forum
+  # ########### Forum
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Forum:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_forum" VALUE="1"'.( ($row_grp['can_use_forum']==1) ? ' CHECKED' : '' ).'>
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_forum" VALUE="1"'.( ($row_grp['can_use_forum']==1) ? ' checked="checked"' : '' ).'>
 can use forum.
 ';
   $i++;
 
-  // ########### Patch
+  # ########### Patch
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Patch manager:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_patch" VALUE="1"'.( ($row_grp['can_use_patch']==1) ? ' CHECKED' : '' ).'> can use patch manager.
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_patch" VALUE="1"'.( ($row_grp['can_use_patch']==1) ? ' checked="checked"' : '' ).'> can use patch manager.
 
 ';
   $i++;
 
-  // ###########  Task
+  # ###########  Task
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Task manager:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_task" VALUE="1"'.( ($row_grp['can_use_task']==1) ? ' CHECKED' : '' ).'> can use task manager.
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_task" VALUE="1"'.( ($row_grp['can_use_task']==1) ? ' checked="checked"' : '' ).'> can use task manager.
 
 ';
   $i++;
 
-  // ###########  News
+  # ###########  News
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>News:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_news" VALUE="1"'.( ($row_grp['can_use_news']==1) ? ' CHECKED' : '' ).'> can use news.
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_news" VALUE="1"'.( ($row_grp['can_use_news']==1) ? ' checked="checked"' : '' ).'> can use news.
 
 ';
   $i++;
 
-  // ###########  Support
+  # ###########  Support
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Support Request Manager:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_support" VALUE="1"'.(($row_grp['can_use_support']==1) ? ' CHECKED' : '' ).'> can use support request tracker.
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_support" VALUE="1"'.(($row_grp['can_use_support']==1) ? ' checked="checked"' : '' ).'> can use support request tracker.
 
 ';
   $i++;
 
-  // ########### Bugs
+  # ########### Bugs
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Bug Tracker:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_bug" VALUE="1"'.(($row_grp['can_use_bug']==1) ? ' CHECKED' : '' ).'> can use bug tracker.';
+<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_bug" VALUE="1"'.(($row_grp['can_use_bug']==1) ? ' checked="checked"' : '' ).'> can use bug tracker.';
 
   $HTML->box1_bottom();
 
@@ -411,11 +424,11 @@ print '
 <input type="submit" name="delete" value="'._("Delete this Group Type").'">';
 
 
-  print '<br><br>';
+  print '<br /><br />';
 
-  // ####################################################################
-  // PROJECTS MENU SETTINGS
-  // ####################################################################
+  # ####################################################################
+  # PROJECTS MENU SETTINGS
+  # ####################################################################
 
   $HTML->box1_top(_("Project Menu Settings"));
   print '<p>This form allows you to choose which menu entries are configurable by the projects administrators.</p>';
@@ -423,8 +436,8 @@ print '
 
   function specific_checkbox ($val, $explanation, $increment=1)
     {
-      // just a little fonction to clean that part of the code, no
-      // interest to generalize it
+      # just a little fonction to clean that part of the code, no
+      # interest to generalize it
       global $i, $row_grp;
       if ($increment)
 	{ $i++; }
@@ -441,6 +454,9 @@ print '
 
   specific_checkbox("download",
 		    _("the download area link can be modified"));
+  $row_grp["is_menu_configurable_download_dir"] = $row_grp["is_configurable_download_dir"];
+  specific_checkbox("download_dir",
+		    _("the download _directory_ can be modified -- beware, if the backend is running and creating download dir, it can be used maliciously. don't activate this feature unless you truly know what you're doing"));
 
   specific_checkbox("support",
 		    _("the support link can be modified"));
@@ -475,13 +491,13 @@ print '
   print '<p align="center"><input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
 <input type="submit" name="delete" value="'._("Delete this Group Type").'">';
 
-  print '<br><br>';
+  print '<br /><br />';
 
-  // ####################################################################
-  // PROJECTS USERS SETTINGS
-  // ####################################################################
+  # ####################################################################
+  # PROJECTS USERS SETTINGS
+  # ####################################################################
 
-  $HTML->box1_top(_("Project Default Users Permissions"));
+  $HTML->box1_top(_("Project Default Member Permissions"));
 
   print '<p>This form allows you to define the default permissions for users added to a group of this type, unless this group defined its own configuration.</p>';
 
@@ -504,6 +520,34 @@ print '
 
   $HTML->box1_bottom();
 
+ print '<p align="center"><input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
+<input type="submit" name="delete" value="'._("Delete this Group Type").'">';
+
+  print '<br /><br />';
+
+  $HTML->box1_top(_("Project Default Posting Restrictions"));
+
+  print '<p>This form allows you to define the default posting restriction on this group trackers.</p>';
+
+  $title_arr=array();
+  $title_arr[]=_("Support Tracking");
+  $title_arr[]=_("Bug Tracking");
+  $title_arr[]=_("Task Tracking");
+  $title_arr[]=_("Patch Tracking");
+  $title_arr[]=_("News Manager");
+  print html_build_list_table_top ($title_arr);
+
+  html_select_restriction_box("support", $row_grp['support_rflags'], "type");
+  html_select_restriction_box("bugs", $row_grp['bugs_rflags'], "type");
+  html_select_restriction_box("task", $row_grp['task_rflags'], "type");
+  html_select_restriction_box("patch", $row_grp['patch_rflags'], "type");
+  html_select_restriction_box("news", $row_grp['news_rflags'], "type");
+  
+  print '  </tr>
+</table>';
+
+  $HTML->box1_bottom();
+
   print '<p align="center">
 <input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
 <input type="submit" name="delete" value="'._("Delete this Group Type").'"></p>
