@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.15 2004/07/22 13:54:14 yeupou Exp $
+# $Id: general.php,v 1.16 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -25,7 +25,7 @@
 
 function news_new_subbox($row)
 {
-  return $row > 1 ? '<tr><td class="'.utils_get_alt_row_color($row).'">' : '';
+  return $row > 1 ? '</div><div class="'.utils_get_alt_row_color($row).'">' : '';
 }
 
 function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_from="no")
@@ -123,7 +123,7 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
 
       $return .=
         news_new_subbox($i+1)
-	.'<a href="'.$GLOBALS['sys_home'].'forum/forum.php?forum_id='.db_result($result,$i,'forum_id').'"><b>'.db_result($result,$i,'summary').'</b></a><br>'
+	.'<a href="'.$GLOBALS['sys_home'].'forum/forum.php?forum_id='.db_result($result,$i,'forum_id').'"><b>'.db_result($result,$i,'summary').'</b></a><br />'
 	.'&nbsp;&nbsp;&nbsp;&nbsp;<i>'._("posted by").' <a href="'
 	.$GLOBALS['sys_home'].'users/'. db_result($result,$i,'user_name') .'">'. db_result($result,$i,'user_name')
 	.'</a>, '. format_date($sys_datefmt,db_result($result,$i,'date')) .' - '.$trow_count.' '
