@@ -2,12 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: project_home.php,v 1.108 2004/08/23 12:30:12 yeupou Exp $
+# $Id: project_home.php,v 1.109 2004/09/22 08:11:51 yeupou Exp $
 #
 # Copyright 1999-2000 (c) The SourceForge Crew
 # Copyright 2000-2003 (c) Free Software Foundation
 #
-# Copyright 2002-2004 (c) Mathieu Roy <yeupou@gnu.org>
+# Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#                         Yves Perrin <yves.perrin--at--cern.ch>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -39,24 +40,60 @@ site_project_header(array('group'=>$group_id,
 			  'toptab'=>'home'));
 
 
-# ########################################### end top area
-
-# two column deal
-
-print '<table width="100%" border="0">
-<tr><td class="indexcenter">';
-
-
-# ########################################## top area, not in box
+# ########################### Members of this project
+# (little box on the right)
 
 $res_admin = db_query("SELECT user.user_id AS user_id,user.user_name AS user_name, user.realname AS realname "
 		      . "FROM user,user_group "
 		      . "WHERE user_group.user_id=user.user_id AND user_group.group_id=$group_id AND "
 		      . "user_group.admin_flags = 'A'");
 
+
+print '
+<div class="indexright">
+';
+
+print $HTML->box_top(_("Membership Info"));
+$adminsnum = db_numrows($res_admin);
+if ($adminsnum > 0)
+{
+
+  print _("Project Admins").':';
+  while ($row_admin = db_fetch_array($res_admin))
+{
+    print "<br />&nbsp; - ".utils_link($GLOBALS['sys_home']."users/".$row_admin[user_name], $row_admin[realname]);
+  }
+}
+
+#count of developers on this project
+$membersnum = db_fetch_array(db_query("SELECT COUNT(*) AS count FROM user_group WHERE group_id=$group_id AND admin_flags<>'P'"));
+print '<br /><br />'._("Members").': <font class="bold">'.$membersnum[count].'</font>';
+
+# if member = 1, it's obviously (or it should be) the project admin
+# if there's no admin, we need to get access to the list
+# But we show it anyway: this page can be used for request for membership,
+# provide more info that the little infobox.
+print '<br />&nbsp; '.utils_link($GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name, "[View&nbsp;&nbsp;Members]");
+
+
+print $HTML->box_bottom();
+print '<br />';
+print $HTML->box_top(_("Group identification"));
+print '&nbsp; - #'.$group_id;
+print '<br />&nbsp; - '.$group_name;
+print $HTML->box_bottom();
+
+
+print '
+</div><!-- end indexright -->
+<div class="indexcenter">
+';
+
+
 # ########################### General Informations
 
-print '<p>'.$project->getTypeDescription()."</p>\n";
+if ($project->getTypeDescription())
+{ print '<p>'.$project->getTypeDescription()."</p>\n"; }
 
 if ($project->getLongDescription())
 {
@@ -80,61 +117,44 @@ if ($project->CanUse("license"))
   $license = $project->getLicense();
   print _("License").' : ';
   if ($LICENSE_URL[$license] != "0")
-{
-    print '<a href="'.$LICENSE_URL[$license].'" target="_blank">'.$LICENSE[$license].'</a>';
-  }
-else
-{
-    print $LICENSE[$license];
-  }
+    { print utils_link($LICENSE_URL[$license], $LICENSE[$license]); }
+  else
+    { print $LICENSE[$license]; }
 }
-print '<br>'._("Registration Date").' : '.format_date($sys_datefmt,$project->getStartDate())."\n";
+print '<br />'._("Registration Date").' : '.format_date($sys_datefmt,$project->getStartDate())."\n";
 if ($project->CanUse("devel_status"))
 {
   $devel_status = $project->getDevelStatus();
-  print '<br>'._("Development Status").' : '.$DEVEL_STATUS[$devel_status]."\n";
+  print '<br />'._("Development Status").' : '.$DEVEL_STATUS[$devel_status]."\n";
 }
-print '</p></td><td nowrap class="indexright">';
+print '</p>
+</div><!-- end indexcenter -->
+<p class="clearr">&nbsp;</p>
+';
 
-# ########################### Members of this project
-# (little box on the right)
+# ############################## ###########################
+# #######################################################################
+# ##############################  ###########################
+# #######################################################################
 
-print $HTML->box1_top(_("Membership Info"));
-$adminsnum = db_numrows($res_admin);
-if ($adminsnum > 0)
-{
+# ########################### News
+
+if ($project->Uses("news")) {
+
+  print '
+<div class="splitright">';
+
+  print $HTML->box_top(_("Latest News"));
+  print news_show_latest($group_id,4,"true");
+  print $HTML->box_bottom();
+
+  print '
+</div><!-- end splitright -->
+<div class="splitleft">
+';
 
-  print _("Project Admins").':';
-  while ($row_admin = db_fetch_array($res_admin))
-{
-    print "<br>&nbsp; - <a href=\"".$GLOBALS['sys_home']."users/$row_admin[user_name]/\">$row_admin[realname]</a>";
-  }
 }
 
-#count of developers on this project
-$membersnum = db_fetch_array(db_query("SELECT COUNT(*) AS count FROM user_group WHERE group_id=$group_id AND admin_flags<>'P'"));
-print '<br><br>'._("Members").': <font class="bold">'.$membersnum[count].'</font>';
-
-# if member = 1, it's obviously (or it should be) the project admin
-# if there's no admin, we need to get access to the list
-# But we show it anyway: this page can be used for request for membership,
-# provide more info that the little infobox.
-print '<br>&nbsp; <a href="'.$GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name.'">[View&nbsp;&nbsp;Members]</a>';
-
-
-print $HTML->box1_bottom();
-print $HTML->box1_top(_("Group identification"));
-print '&nbsp; - #'.$group_id;
-print '<br>&nbsp; - '.$group_name;
-print $HTML->box1_bottom();
-
-
-print '</td></tr></table>';
-print '<p></p>';
-print '<table width="100%">';
-print '<tr><td valign="top" width="50%">'."\n\n";
-
-
 # ############################## ADMIN AREA ###########################
 # #######################################################################
 
@@ -143,37 +163,35 @@ if ($GLOBALS[sys_group_id] == $group_id)
   if (member_check(0, $group_id, 'A'))
     {
       require $GLOBALS['sys_urlroot']."/include/features_boxes.php";
-      print $HTML->box1_top(sprintf(_("Administration: %s server"), $GLOBALS['sys_name']));
+      print $HTML->box_top(sprintf(_("Administration: %s server"), $GLOBALS['sys_name']));
       print sprintf(_("Since you are administrator of this project, which one is the \"system project\", you are administrator of the whole %s server."), $GLOBALS['sys_name']);
 
-      print '</td></tr><tr><td colspan="2" class="'.utils_get_alt_row_color($i).'">'."\n\n";
+      print $HTML->box_nextitem(utils_get_alt_row_color($i));
 
-      print '<a href="'.$GLOBALS['sys_home'].'admin/">';
-      html_image("admin.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Server Admin")));
-      print '&nbsp;'._("Server Main Administration Page").'</a>';
+      print utils_link($GLOBALS['sys_home'].'admin/',
+		      html_image("admin.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Server Admin"))).'&nbsp;'._("Server Main Administration Page"));
 
-      print '</td></tr><tr><td colspan="2" class="'.utils_get_alt_row_color($i+1).'">'."\n\n";
+      print $HTML->box_nextitem(utils_get_alt_row_color($i+1));
 
-      print '<a href="'.$GLOBALS['sys_home'].'admin/approve-pending.php">';
-      html_image("admin.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Server Admin")));
-      print '&nbsp;'._("Pending Projects List").'</a> ( <b>'.number_format(stats_getprojects_pending()).'</b> '._("registrations pending").' )';
-      $HTML->box1_bottom();
-      print '<br>';
+      print utils_link($GLOBALS['sys_home'].'admin/approve-pending.php',
+		       html_image("admin.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Server Admin"))).'&nbsp;'._("Pending Projects List"));
+      print ' (<b>'.number_format(stats_getprojects_pending()).'</b> '._("registrations pending").')';
+      print $HTML->box_bottom();
+      print '<br />';
     }
 }
 
 if (member_check(0, $group_id, 'A'))
 {
-  print $HTML->box1_top(sprintf(_("Administration: %s project"), $project->getName()));
-  print _("As administrator of this project, you can manage members and activate/deactivate/configure the Savannah tools for your project.");
+  print $HTML->box_top(sprintf(_("Administration: %s project"), $project->getName()));
+  print _("As administrator of this project, you can manage members and activate/deactivate/configure your project's tools.");
 
-  print '</td></tr><tr><td colspan="2" class="'.utils_get_alt_row_color($i).'">'."\n\n";
+  print $HTML->box_nextitem(utils_get_alt_row_color($i));
 
-  print '<a href="'.$GLOBALS['sys_home'].'project/admin/?group='.$group_name.'">';
-  html_image("main.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Admin Page")));
-  print '&nbsp;'._("Project Main Administration Page").'</a>';
-  $HTML->box1_bottom();
-  print '<br>';
+  print utils_link($GLOBALS['sys_home'].'project/admin/?group='.$group_name,
+		  html_image("main.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Admin Page"))).'&nbsp;'._("Project Main Administration Page"));
+  print $HTML->box_bottom();
+  print '<br />';
 }
 
 
@@ -185,24 +203,23 @@ if (member_check(0, $group_id, 'A'))
 function specific_makesep ()
 {
   # too specific to be general function
-  global $i, $j;
+  global $i, $j, $HTML;
   if ($i != $j)
     {
-      print '</td></tr><tr><td colspan="2" class="'.utils_get_alt_row_color($i).'">'."\n\n";
+      print $HTML->box_nextitem(utils_get_alt_row_color($i));
       $j = $i;
     }
 }
 
-print $HTML->box1_top(_("Public Areas: Quick Overview"));
+print $HTML->box_top(_("Public Areas: Quick Overview"));
 $i = 1;
 $j = $i;
 # Homepage Link
 
 if ($project->Uses("homepage"))
 {
-  print "<a href=\"".$project->getUrl("homepage")."\">";
-  html_image("www.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Homepage")));
-  print '&nbsp;'._("Project Homepage").'</a>';
+  print utils_link($project->getUrl("homepage"),
+		   html_image("www.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Homepage"))).'&nbsp;'._("Project Homepage"));
   $i++;
 }
 
@@ -211,9 +228,8 @@ if ($project->Uses("extralink_documentation"))
 {
   specific_makesep();
 
-  print '<a href="'.$project->getUrl("extralink_documentation").'">';
-  html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Documentation")));
-  print '&nbsp;'._("Documentation").'</a>';
+  print utils_link($project->getUrl("extralink_documentation"),
+		   html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Documentation"))).'&nbsp;'._("Documentation"));
   $i++;
 }
 
@@ -223,21 +239,19 @@ if($project->Uses("download")) {
 
   # the pointer is always the filelist, this page will handle redirect
   # appropriately in case that no download area is here
-  print '<a href="'.$project->getArtifactUrl("files").'">';
-  print html_image("download.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Filelist'));
-  print '&nbsp;'._("Filelist").' ('._("Download area").')</a>';
+  print utils_link($project->getArtifactUrl("files"),
+		   html_image("download.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Filelist')).'&nbsp;'._("Filelist").' ('._("Download area").')');
   $i++;
 }
 
 # Memberlist
 specific_makesep();
-print '<a href="'.$GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name.'">';
-print html_image("people.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Memberlist'));
-print '&nbsp;'._("Project Memberlist").'</a>';
+print utils_link($GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name,
+		 html_image("people.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Memberlist')).'&nbsp;'._("Project Memberlist"));
 $i++;
 
-$HTML->box1_bottom();
-print '<br>';
+print $HTML->box_bottom();
+print '<br />';
 
 
 # ################################## COMMUNICATION
@@ -249,14 +263,13 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
     people_project_jobs_rows($group_id) != 0)
 {
 
-  print $HTML->box1_top(_("Public Areas: Communication Tools"));
+  print $HTML->box_top(_("Public Areas: Communication Tools"));
   $i = 1;
   $j = $i;
 
   if ($GLOBALS[sys_unix_group_name] == $group_name) {
-    print '<a href="'.$GLOBALS['sys_home'].'faq/?group='.$group_name.'">';
-    html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Frequently Asked Questions")));
-    print '&nbsp;'._("Frequently Asked Questions").'</a>';
+    print utils_link($GLOBALS['sys_home'].'faq/?group='.$group_name,
+		     html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Frequently Asked Questions"))).'&nbsp;'._("Frequently Asked Questions"));
     $i++;
   }
 
@@ -267,21 +280,20 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
     specific_makesep();
     $url = $project->getArtifactUrl("support");
 
-    print '<a href="'.$url.'">';
-    html_image("help.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Tech Support Manager")));
-    print '&nbsp;'._("Tech Support Manager").'</a>';
+    print utils_link($url,
+		     html_image("help.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Tech Support Manager"))).'&nbsp;'._("Tech Support Manager"));
 
     if (group_get_artifact_url("support", 0) == $url)
       {
 
 	$res_count = db_query("SELECT count(*) AS count FROM support WHERE group_id=$group_id AND status_id != 3");
 	$row_count = db_fetch_array($res_count);
-	print " (&nbsp;<b>$row_count[count]</b>";
+	print " (<b>$row_count[count]</b>";
 	$res_count = db_query("SELECT count(*) AS count FROM support WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
-	print ' '._("open requests").", <b>$row_count[count]</b> "._("total")."&nbsp;)\n";
-	print '<br> &nbsp; - <a href="'.$url.'&amp;func=additem">'._("Submit a Request").'</a>';
-	print '<br> &nbsp; - <a href="'.$url.'&amp;func=browse&amp;set=open">'._("Browse Open Requests").'</a>';
+	print ' '._("open requests").", <b>$row_count[count]</b> "._("total").")\n";
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Request"), 0, group_restrictions_check($group_id, "support"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Requests"));
       }
 
     $i++;
@@ -296,9 +308,8 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
 
     $url = $project->getArtifactUrl("forum");
 
-    print '<a href="'.$url.'">';
-    html_image("help.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Public Forum")));
-    print '&nbsp;'._("Public Forum").'</a>';
+    print utils_link($url,
+		     html_image("help.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Public Forum"))).'&nbsp;'._("Public Forum"));
 
     if (group_get_artifact_url("forum", 0) == $url)
       {
@@ -307,13 +318,13 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
 			      . "forum_group_list.group_id=$group_id AND forum.group_forum_id=forum_group_list.group_forum_id "
 			      . "AND forum_group_list.is_public=1");
 	$row_count = db_fetch_array($res_count);
-	print ' (&nbsp;<b>'.$row_count[count].'</b> '._("messages in");
+	print ' (<b>'.$row_count[count].'</b> '._("messages in");
 
 	$res_count = db_query("SELECT count(*) AS count FROM forum_group_list WHERE group_id=$group_id "
 			      . "AND is_public=1");
 	$row_count = db_fetch_array($res_count);
 
-	print " <b>$row_count[count]</b> "._("forums")."&nbsp;)\n";
+	print " <b>$row_count[count]</b> "._("forums").")\n";
       }
     $i++;
 
@@ -325,13 +336,12 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
     {
       specific_makesep();
       $url = $project->getArtifactUrl("mail");
-
-      print '<a href="'.$url.'">';
-      html_image("mail.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Mailing Lists")));
-      print '&nbsp;'._("Mailing Lists").'</a>';
+   
+      print utils_link($url,
+		       html_image("mail.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Mailing Lists"))).'&nbsp;'._("Mailing Lists"));
       $res_count = db_query("SELECT count(*) AS count FROM mail_group_list WHERE group_id=$group_id AND is_public=1");
       $row_count = db_fetch_array($res_count);
-      print " (&nbsp;<b>$row_count[count]</b> "._("public mailing lists")."&nbsp;)";
+      print " (<b>$row_count[count]</b> "._("public mailing lists").")";
       $i++;
     }
 
@@ -339,15 +349,14 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
 
   if (people_project_jobs_rows($group_id) != 0) {
     specific_makesep();
-    print '<a href="'.$GLOBALS['sys_home'].'people/?group='.$group_name.'">';
-    html_image("people.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("People")));
-    print '&nbsp;'._("This project is looking for people").'</a>';
-    print ' (&nbsp;<b>'.people_project_jobs_rows($group_id).'</b> '._("jobs").'&nbsp;)';
+    print utils_link($GLOBALS['sys_home'].'people/?group='.$group_name,
+		     html_image("people.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("People"))).'&nbsp;'._("This project is looking for people"));
+    print ' (<b>'.people_project_jobs_rows($group_id).'</b> '._("jobs").')';
     $i++;
   }
 
-  $HTML->box1_bottom();
-  print '<br>';
+  print $HTML->box_bottom();
+  print '<br />';
 }
 
 # ################################## DEVELOPMENT
@@ -359,7 +368,7 @@ if ($project->Uses("patch") ||
     $project->Uses("task") ||
     $project->Uses("patch"))
 {
-  print $HTML->box1_top(_("Public Areas: Development Tools"));
+  print $HTML->box_top(_("Public Areas: Development Tools"));
   $i = 1;
   $j = $i;
 
@@ -375,7 +384,7 @@ if ($project->Uses("patch") ||
 
       if ($project->getUrl("cvs_viewcvs") != 'http://' && $project->getUrl("cvs_viewcvs") != '' && $project->Uses("cvs"))
 	{
-	  print '<br> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs").'">'._("Browse Sources Repository").'</a>';
+	  print '<br /> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs").'">'._("Browse Sources Repository").'</a>';
 	}
       if ($project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '' && $project->Uses("homepage"))
 	{
@@ -384,7 +393,7 @@ if ($project->Uses("patch") ||
 	  # Only the backend should make use of the is_homepage_on_cvs value,
 	  # because and homepage can be on CVS with this flag off: this flag
 	  # is used to determine whether a CVSROOT must be created or not
-	  print '<br> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs_homepage").'">'._("Browse Web Pages Repository").'</a>';
+	  print '<br /> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs_homepage").'">'._("Browse Web Pages Repository").'</a>';
 	}
       $i++;
     }
@@ -395,20 +404,19 @@ if ($project->Uses("patch") ||
     specific_makesep();
     $url = $project->getArtifactUrl("bugs");
 
-    print '<a href="'.$url.'">';
-    html_image("bug.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Bug Tracking")));
-    print '&nbsp;'._("Bug Tracking").'</a>';
-
+    print utils_link($url,
+		     html_image("bug.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Bug Tracking"))).'&nbsp;'._("Bug Tracking"));
+    
     if (group_get_artifact_url("bugs", 0) == $url)
       {
 	$res_count = db_query("SELECT count(*) AS count FROM bugs WHERE group_id=$group_id AND status_id != 3");
 	$row_count = db_fetch_array($res_count);
-	print " (&nbsp;<b>$row_count[count]</b>";
+	print " (<b>$row_count[count]</b>";
 	$res_count = db_query("SELECT count(*) AS count FROM bugs WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
-	print ' '._("open bugs").", <b>$row_count[count]</b> "._("total")."&nbsp;)\n";
-	print '<br> &nbsp; - <a href="'.$url.'&amp;func=additem">'._("Submit a Bug").'</a>';
-	print '<br> &nbsp; - <a href="'.$url.'&amp;func=browse&amp;set=open">'._("Browse Open Bugs").'</a>';
+	print ' '._("open bugs").", <b>$row_count[count]</b> "._("total").")\n";
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Bug"), 0, group_restrictions_check($group_id, "bugs"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Bugs"));
       }
     $i++;
   }
@@ -420,20 +428,19 @@ if ($project->Uses("patch") ||
     specific_makesep();
     $url = $project->getArtifactUrl("task");
 
-    print '<a href="'.$url.'">';
-    html_image("task.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Task Manager")));
-    print '&nbsp;'._("Task Manager").'</a>';
+    print utils_link($url,
+		     html_image("task.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Task Manager"))).'&nbsp;'._("Task Manager"));
 
     if (group_get_artifact_url("task", 0) == $url)
       {
 	$res_count = db_query("SELECT count(*) AS count FROM task WHERE group_id=$group_id AND status_id != 3");
 	$row_count = db_fetch_array($res_count);
-	print " (&nbsp;<b>$row_count[count]</b>";
+	print " (<b>$row_count[count]</b>";
 	$res_count = db_query("SELECT count(*) AS count FROM task WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
-	print ' '._("open tasks").", <b>$row_count[count]</b> "._("total")."&nbsp;)\n";
-	print '<br> &nbsp; - <a href="'.$url.'">'._("Submit a Task").'</a>';
-	print '<br> &nbsp; - <a href="'.$url.'&amp;func=browse&amp;set=open">'._("Browse Open Tasks").'</a>';
+	print ' '._("open tasks").", <b>$row_count[count]</b> "._("total").")\n";
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Task"), 0, group_restrictions_check($group_id, "task"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Tasks"));
       }
     $i++;
   }
@@ -445,47 +452,36 @@ if ($project->Uses("patch") ||
     specific_makesep();
     $url = $project->getArtifactUrl("patch");
 
-    print '<a href="'.$url.'">';
-    html_image("attach.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Patch Manager")));
-    print '&nbsp;'._("Patch Manager").'</a>';
+    print utils_link($url,
+		     html_image("attach.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Patch Manager"))).'&nbsp;'._("Patch Manager"));
 
 
     if (group_get_artifact_url("patch", 0) == $url)
       {
 	$res_count = db_query("SELECT count(*) AS count FROM patch WHERE group_id=$group_id AND status_id != 3");
 	$row_count = db_fetch_array($res_count);
-	print " (&nbsp;<b>$row_count[count]</b>";
+	print " (<b>$row_count[count]</b>";
 	$res_count = db_query("SELECT count(*) AS count FROM patch WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
-	print ' '._("open patch").", <b>$row_count[count]</b> "._("total")."&nbsp;)\n";
-	print '<br> &nbsp; - <a href="'.$url.'&amp;func=additem">'._("Submit a Patch").'</a>';
-	print '<br> &nbsp; - <a href="'.$url.'&amp;func=browse&amp;set=open">'._("Browse Open Patches").'</a>';
+	print ' '._("open patch").", <b>$row_count[count]</b> "._("total").")\n";
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Patch"), 0, group_restrictions_check($group_id, "patch"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Patches"));
       }
     $i++;
   }
 
-  $HTML->box1_bottom();
+  print $HTML->box_bottom();
 }
 
+
 # ########################### News
 
 if ($project->Uses("news")) {
-
-  print '	</td>
-	<td width="15">&nbsp;</td>
-	<td valign="top">
-	';
-
-  # ############################# Latest News
-
-  print $HTML->box1_top(_("Latest News"));
-  print news_show_latest($group_id,4,"true");
-  print $HTML->box1_bottom();
+  print '
+</div><!-- end splitleft -->
+';
 }
 
-print '</td>
-</tr></table>';
-
 
 site_project_footer(array());
 
