@@ -2,12 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.8 2004/03/26 18:45:45 yeupou Exp $
+# $Id: general.php,v 1.11 2004/09/24 07:37:35 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#                          Yves Perrin <yves.perrin--at--cern.ch>
 #
 #
 # This program is free software; you can redistribute it and/or
@@ -180,7 +181,7 @@ function trackers_field_label_display($field_name, $group_id,$break=false,$ascii
   if (!$ascii) 
     { $output = '<font class="preinput"><font class="help" title="'.trackers_data_get_description($field_name).'">'.$output.'</font></font>'; }
   if ($break) 
-    { $output .= ($ascii?"\n":'<br>'); }
+    { $output .= ($ascii?"\n":'<br />'); }
   else
     { $output .= ($ascii? ' ':'&nbsp;'); }
   return $output;
@@ -196,10 +197,10 @@ function trackers_field_display ($field_name,
 				 $show_none=false, 
 				 $text_none='None',
 				 $show_any=false, 
-				 $text_any='Any')
+				 $text_any='Any',
+                                 $allowed_transition_only=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_display  ';			
-
   /*
           Display a bug field either as a read-only value or as a read-write 
           making modification possible
@@ -218,7 +219,9 @@ function trackers_field_display ($field_name,
           - text_none: text associated with the none value_id to display in the select box
           - show_any: show the Any entry in the select box if true (value_id 0)
           - text_any: text associated with the any value_id  tp display in the select box
+          - allowed_transition_only: print only transition allowed
   */
+
   global $sys_datefmt;
 
   if ($label)
@@ -234,19 +237,19 @@ function trackers_field_display ($field_name,
       if ($ro)
 	{
 
-	  # if multiple selected values return a list of <br> separated values
+	  # if multiple selected values return a list of <br /> separated values
 	  $arr = ( is_array($value) ? $value : array($value));
 	  for ($i=0;$i < count($arr); $i++)
 	    {
 	      if ($arr[$i] == 0 )
-		$arr[$i] = $text_any;
-	      else if ($arr[$i] == 100 )
-		$arr[$i] = $text_none;
+		{ $arr[$i] = $text_any; }
+	      else if ($arr[$i] == 100 && $field_name != 'percent_complete')
+		{ $arr[$i] = $text_none; }
 	      else 
-		$arr[$i] = trackers_data_get_value($field_name,$group_id,$arr[$i]);
+		{ $arr[$i] = trackers_data_get_value($field_name,$group_id,$arr[$i]); }
 	    }
 
-	  $output .= join('<br>', $arr);
+	  $output .= join('<br />', $arr);
 
 	}
       else
@@ -260,43 +263,49 @@ function trackers_field_display ($field_name,
 	    }
 	
 	  if (is_array($value))
-	    $output .= trackers_multiple_field_box($field_name,'',$group_id, $value,
-						   $show_none,$text_none,$show_any,
-						   $text_any);
+	    { 
+	      $output .= trackers_multiple_field_box($field_name,'',$group_id, $value,
+						     $show_none,$text_none,$show_any,
+						     $text_any);
+	    }
 	  else
-	    $output .= trackers_field_box($field_name,'',$group_id, $value,
-					  $show_none,$text_none,$show_any,
-					  $text_any);
+	    {
+	      $output .= trackers_field_box($field_name,'',$group_id, $value,
+					    $show_none,$text_none,$show_any,
+					    $text_any, $allowed_transition_only);
+	    }
 	}
       break; 
 
     case 'DF':
       if ($ascii) 
-	$output .= ( ($value == 0) ? '' : format_date($sys_datefmt,$value));
+	{ 
+	  $output .= ( ($value == 0) ? '' : format_date($sys_datefmt,$value)); 
+	}
       else
-	if ($ro)
-	  {
-	    $output .= format_date($sys_datefmt,$value);
-	  }
+	{
+	  if ($ro)
+	    { $output .= format_date($sys_datefmt,$value); }
 	else
 	  {
 	    $output .= trackers_field_date($field_name,
 					   (($value == 0) ? '' : format_date("Y-m-j",$value,'')));
 	  }
+	}
       break;
 
     case 'TF':
       if ($ascii) 
-	$output .= utils_unconvert_htmlspecialchars($value);
+	{ $output .= utils_unconvert_htmlspecialchars($value); }
       else
-	$output .= ($ro ? $value: trackers_field_text($field_name,$value));
+	{ $output .= ($ro ? $value: trackers_field_text($field_name,$value)); }
       break;
 
     case 'TA':
       if ($ascii) 
-	$output .= utils_unconvert_htmlspecialchars($value);
+	{ $output .= utils_unconvert_htmlspecialchars($value); }
       else
-	$output .= ($ro ? nl2br($value):trackers_field_textarea($field_name,$value));
+	{ $output .= ($ro ? nl2br($value):trackers_field_textarea($field_name,$value)); }
       break;
 
     default:
@@ -349,7 +358,7 @@ function trackers_multiple_field_date($field_name,$date_begin='',$date_end='',$s
 
   if ($ro)
     if ($date_begin || $date_end)
-      $html = "Start:&nbsp;$date_begin<br>End:&nbsp;$date_end";
+      $html = "Start:&nbsp;$date_begin<br />End:&nbsp;$date_end";
     else
       $html = 'Any time';
   else
@@ -357,15 +366,15 @@ function trackers_multiple_field_date($field_name,$date_begin='',$date_end='',$s
       if (!$size || !$maxlength)
 	list($size, $maxlength) = trackers_data_get_display_size($field_name);
 
-      $html = 'Start:<br><INPUT TYPE="text" name="'.$field_name.
+      $html = 'Start:<br /><INPUT TYPE="text" name="'.$field_name.
 	 '" size="'.$size.'" MAXLENGTH="'.$maxlength.'" VALUE="'.$date_begin.'">'.
 	 '<a href="javascript:show_calendar(\'document.bug_form.'.$field_name.'\', document.bug_form.'.$field_name.'.value);">'.
-	 '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/task.png" border="0" alt="'._("Click Here to Pick up a date").'"></a>'.
+	 '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/task.png" border="0" alt="'._("Click Here to Pick up a date").'" /></a>'.
 	 '</td></tr><tr><td>'.
-	 'End:<br><INPUT TYPE="text" name="'.$field_name.'_end'.
+	 'End:<br /><INPUT TYPE="text" name="'.$field_name.'_end'.
 	 '" size="'.$size.'" MAXLENGTH="'.$maxlength.'" VALUE="'.$date_end.'">'.
 	 '<a href="javascript:show_calendar(\'document.bug_form.'.$field_name.'_end\', document.bug_form.'.$field_name.'_end.value);">'.
-	 '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/task.png" border="0" alt="'._("Click Here to Pick up a date").'"></a>';
+	 '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/task.png" border="0" alt="'._("Click Here to Pick up a date").'" /></a>';
     
       $html = '<table><tr><td>'.$html.'</td></tr></table>';
     }
@@ -416,27 +425,83 @@ function trackers_field_textarea($field_name,$value='',$cols=0,$rows=0)
 
 }
 
-function trackers_field_box($field_name,$box_name='',$group_id,$checked=false,$show_none=false,$text_none='None',$show_any=false, $text_any='Any')
+function trackers_field_box($field_name,$box_name='',$group_id,$checked=false,$show_none=false,$text_none='None',$show_any=false, $text_any='Any', $allowed_transition_only=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_box ';
 
-  /*
-      Returns a select box populated with field values for this project
-      if box_name is given then impose this name in the select box
-      of the  HTML form otherwise use the field_name)
-  */
+  # Returns a select box populated with field values for this project
+  # if box_name is given then impose this name in the select box
+  # of the  HTML form otherwise use the field_name
+
   if (!$group_id)
-    {
-      return 'ERROR - no group_id';
-    }
+    { return 'ERROR - no group_id'; }
   else
     {
       $result = trackers_data_get_field_predefined_values($field_name,$group_id,$checked);
-
+      
       if ($box_name == '')
+	{ $box_name = $field_name; }
+      
+      if ($allowed_transition_only) 
 	{
-	  $box_name = $field_name;
-	}
+          # yeupou--gnu.org 2004-09-12: where the hell is by_field_id set?
+	  $field_id = ($by_field_id ? $field_name : trackers_data_get_field_id($field_name));
+
+          # first check if group has defined transitions for this field
+	  $default_auth = db_result(db_query("SELECT transition_default_auth ".
+					     "FROM ".ARTIFACT."_field_usage ".
+					     "WHERE group_id='$group_id' AND bug_field_id='$field_id'"), 0, 'transition_default_auth');
+	  # avoid corrupted database content, if it's not F, it must be A.
+	  if ($default_auth != "F")
+	    { $default_auth = "A"; }
+	  
+	  $sql="SELECT from_value_id,to_value_id,is_allowed,notification_list ".
+	     "FROM trackers_field_transition ".
+	     "WHERE group_id='$group_id' AND artifact='".ARTIFACT."' AND field_id='$field_id' AND (from_value_id='$checked' OR from_value_id='0')";
+	  
+	  $trans_result = db_query($sql);
+	  $forbidden_to_id = array();
+	  $allowed_to_id = array();
+	  $rows = db_numrows($trans_result);
+	  if ($trans_result && $rows > 0 || $default_auth == "F")
+	    {
+	      while ($transition = db_fetch_array($trans_result))
+		{
+		  if ($transition['is_allowed'] == 'F') 
+		    {
+		      $forbidden_to_id[$transition['to_value_id']] = 0;
+		    } 
+		  else 
+		    {
+		      $allowed_to_id[$transition['to_value_id']] = 0;
+		    }
+		}
+	      
+	      # get all the predefined values for this field
+	      $rows=db_numrows($result);
+
+	      if ($rows > 0) {
+		$val_label = array();
+		while ($val_row = db_fetch_array($result))
+		  {
+		    $value_id = $val_row['value_id'];
+		    $value   = $val_row['value'];
+		    if ((($default_auth == 'A') && (!array_key_exists($value_id, $forbidden_to_id))) ||
+			(($default_auth == 'F') && (array_key_exists($value_id, $allowed_to_id))) ||
+			($value_id == $checked)) 
+		      {
+			$val_label[$value_id] = $value;
+		      }
+		  }
+ 
+                # always add the any values cases
+		return html_build_select_box_from_arrays (array_keys($val_label),array_values($val_label),$box_name,$checked,$show_none,$text_none,$show_any, $text_any);
+          }
+        }
+      } 
+      
+# if no transition defined use 'normal' code
+      
       return html_build_select_box ($result,$box_name,$checked,$show_none,$text_none,$show_any, $text_any);
     }
 }
@@ -445,11 +510,10 @@ function trackers_multiple_field_box($field_name,$box_name='',$group_id,$checked
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_multiple_field_box )';
 
-  /*
-      Returns a multiplt select box populated with field values for this project
-      if box_name is given then impose this name in the select box
-      of the  HTML form otherwise use the field_name)
-  */
+  # Returns a multiplt select box populated with field values for this project
+  # if box_name is given then impose this name in the select box
+  # of the  HTML form otherwise use the field_name)
+
   if (!$group_id)
     {
       return 'ERROR - no group_id';
@@ -497,9 +561,9 @@ function trackers_extract_field_list($post_method=true)
 	      # get what we already have
 	      list($year, $month, $day) = split("-", $vfl[$field_name]);
 	      if ($field_name_part  == 'day')
-		{ $vfl[$field_name] = "$year-$month-".($val+1); }
+		{ $vfl[$field_name] = "$year-$month-$val"; }
 	      elseif ($field_name_part == 'month')
-		{ $vfl[$field_name] = "$year-".($val+1)."-$day"; }
+		{ $vfl[$field_name] = "$year-$val-$day"; }
 	      elseif ($field_name_part == 'year')
 		{ $vfl[$field_name] = "$val-$month-$day"; }
 	    }
@@ -624,7 +688,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
   if (!$arr_notif)
     { return true; }
 
-  #echo "==== DBG Checking Notif. for $user_id (role=$role)<br>";
+  #echo "==== DBG Checking Notif. for $user_id (role=$role)<br />";
   $user_name = user_getname($user_id);
 
   #----------------------------------------------------------
@@ -634,12 +698,12 @@ function trackers_check_notification($user_id, $role, $changes=false)
     {
       if ($arr_notif[$role]['NEW_ITEM'])
 	{
-	  #echo "DBG NEW_ITEM notified<br>";
+	  #echo "DBG NEW_ITEM notified<br />";
 	  return true;
 	}
       else
 	{
-	  #echo "DBG No notification<br>";
+	  #echo "DBG No notification<br />";
 	  return false;
 	}
     }
@@ -650,7 +714,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
   # aware of any of her change in this role and we can return immediately.
   if (($user_id == user_getid()) && !$arr_notif[$role]['I_MADE_IT'])
     {
-      #echo "DBG Dont want to receive my own changes<br>";
+      #echo "DBG Dont want to receive my own changes<br />";
       return false;
     }
     
@@ -658,7 +722,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
   # Check :  NEW_COMMENT  A new followup comment is added 
   if ($arr_notif[$role]['NEW_COMMENT'] && isset($changes['details']))
     {
-      #echo "DBG NEW_COMMENT notified<br>";
+      #echo "DBG NEW_COMMENT notified<br />";
       return true;
     }
 
@@ -666,7 +730,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
   #Check: NEW_FILE  (A new file attachment is added)
   if ($arr_notif[$role]['NEW_FILE'] && isset($changes['attach']))
     {
-      #echo "DBG NEW_FILE notified<br>";
+      #echo "DBG NEW_FILE notified<br />";
       return true;
     }
   
@@ -676,7 +740,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
   # says no.
   if ($arr_notif[$role]['CLOSED'] && ($changes['status_id']['add'] == 'Closed'))
     {
-      #echo "DBG CLOSED bug notified<br>";
+      #echo "DBG CLOSED bug notified<br />";
       return true;
     }
 
@@ -685,7 +749,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
   if ($arr_notif[$role]['PSS_CHANGE'] && 
       (isset($changes['priority']) || isset($changes['status_id']) || isset($changes['severity'])) )
     {
-      #echo "DBG PSS_CHANGE notified<br>";
+      #echo "DBG PSS_CHANGE notified<br />";
       return true;
     }
 
@@ -700,7 +764,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
       (($changes['submitted_by']['add'] == $user_name) || ($changes['submitted_by']['del'] == $user_name)) &&
       ($role == 'SUBMITTER') )
     {
-      #echo "DBG ROLE_CHANGE for submitter notified<br>";
+      #echo "DBG ROLE_CHANGE for submitter notified<br />";
       return true;
     }
 
@@ -708,7 +772,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
       (($changes['assigned_to']['add'] == $user_name) || ($changes['assigned_to']['del'] == $user_name)) &&
       ($role == 'ASSIGNEE') )
     {
-      #echo "DBG ROLE_CHANGE for role assignee notified<br>";
+      #echo "DBG ROLE_CHANGE for role assignee notified<br />";
       return true;
     }
 
@@ -724,7 +788,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
     {
       if ($is_user_in_cc_changes)
 	{
-	  #echo "DBG ROLE_CHANGE for cc notified<br>";
+	  #echo "DBG ROLE_CHANGE for cc notified<br />";
 	  return true;
 	}
     }
@@ -742,7 +806,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
       # notified on role_change as CC, unless other users are listed in the cc changes
       if (($role != 'CC') || (($role == 'CC') && $are_anyother_user_in_cc_changes))
 	{
-	  #echo "DBG CC_CHANGE notified<br>";
+	  #echo "DBG CC_CHANGE notified<br />";
 	  return true; 
 	}
     }
@@ -764,12 +828,12 @@ function trackers_check_notification($user_id, $role, $changes=false)
   unset($changes['submitted_by']);
   if ($arr_notif[$role]['ANY_OTHER_CHANGE'] && count($changes))
     {
-      #echo "DBG ANY_OTHER_CHANGE notified<br>";
+      #echo "DBG ANY_OTHER_CHANGE notified<br />";
       return true;
     }
 
   # Sorry, no notification...
-  #echo "DBG No notification!!<br>";
+  #echo "DBG No notification!!<br />";
   return false;
 }
 
@@ -864,10 +928,13 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
       while ($row = db_fetch_array($res_com))
 	{
 	  $user_id = $row['mod_by'];
-	  if (!$user_ids[$user_id] && trackers_check_notification($user_id, 'COMMENTER', $changes))
-	    {
-	      $user_ids[$user_id] = true;
-	    }
+          if ($user_id != 100) 
+            {
+              if (!$user_ids[$user_id] && trackers_check_notification($user_id, 'COMMENTER', $changes))
+	        {
+	          $user_ids[$user_id] = true;
+	        }
+            }
 	}
     }
 
@@ -876,9 +943,11 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
   while (list($user_id,) = each($user_ids))
     {
       if ($user_id)
-	{ # Dirty hack: for a reason need to be cleared out,
+	{ 
+          # Dirty hack: for a reason need to be cleared out,
 	  # a user_id = 0 arrived here.
-	  $addresses[user_getemail($user_id)] = true;
+          # Must not define email address so soon. Just passing user_id
+	  $addresses[$user_id] = true;
 	}
     }
 
@@ -891,10 +960,7 @@ function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_mail_followup($item_id,$more_addresses=false,$changes=false)';
   global $sys_datefmt,$feedback,$ffeedback;
-  /*
-      Send a message to the person who opened this bug and the person it is assigned to - 
-      modified by jstidd on 1/30/01 to eliminate default user assigned to
-  */
+
   $sql="SELECT * from ".ARTIFACT." WHERE bug_id='$item_id'";
 
   $result=db_query($sql);
@@ -977,7 +1043,7 @@ function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
       # given at the end of the list.
       $arr_addresses = trackers_build_notification_list($item_id,$group_id,$changes);
       $to = join(',',$arr_addresses);
-      $from = user_getrealname(0,1).' <noreply@'.$GLOBALS['sys_default_domain'].'>';
+      $from = user_getrealname(0,1).' <'.$GLOBALS['sys_mail_replyto'].'@'.$GLOBALS['sys_mail_domain'].'>';
       $subject = utils_unconvert_htmlspecialchars(db_result($result,0,'summary'));
 
       if ($more_addresses)
@@ -987,7 +1053,8 @@ function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
 
       sendmail_mail($from, $to, $subject, $body, group_getunixname($group_id), ARTIFACT, $item_id);
 
-      fb(_("Item update sent.")); 
+      # Useless feedback, already added by sendmail_mail()
+      #fb(_("Item update sent.")); 
 
     }
   else
@@ -1010,17 +1077,28 @@ function trackers_attach_file($item_id,
 
   $user_id = (user_isloggedin() ? user_getid(): 100);
 
+  # Open the file
   $data = fopen($input_file, 'r');
   if (!$data) 
     {
-      fb(_("File not attached: unable to open it (fopen failure)."), 0);
+      fb(_("File not attached: unable to open it."), 1);
       return false;
     }
   
+  # Check file size:
+  #  - first with filesize(), that can result appropriate result for big files
+  #  unlike strlen. If it is too big, we stop here.
+  #  - then with strlen after the call the addslashes(): the check must be 
+  #  made on the final size for import in the database.
+  # 
+  if (filesize($input_file) > 512000) {
+    fb(_("File not attached: must be > 20 chars and < 512000 chars in length, after escaping characters as required."), 1);
+    return false;
+  }
   $data = addslashes(fread($data, filesize($input_file)));
   if ((strlen($data) < 20) || (strlen($data) > 512000))
     {
-      fb(_("File not attached: must be > 20 chars and < 512000 chars in length."), 0);
+      fb(sprintf(_("File not attached: must be > 20 chars and < 512000 chars in length. After escaping characters as required, it sized %s."), strlen($data)), 1);
       return false;
     }
 
@@ -1032,7 +1110,7 @@ function trackers_attach_file($item_id,
 
   if (!$res)
     {
-      fb(_("Error while attaching file:").' '.db_error($res), 0);
+      fb(_("Error while attaching file:").' '.db_error($res), 1);
       return false;
     }
   else
@@ -1218,7 +1296,7 @@ function trackers_isvarany($var)
 function trackers_add_sort_criteria($criteria_list, $order, $msort)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_add_sort_criteria($criteria_list, $order, $msort)';
-  #echo "<br>DBG \$criteria_list=$criteria_list,\$order=$order";
+  #echo "<br />DBG \$criteria_list=$criteria_list,\$order=$order";
 
   if ($criteria_list)
     {
@@ -1228,7 +1306,7 @@ function trackers_add_sort_criteria($criteria_list, $order, $msort)
 	{
 	  preg_match("/\s*([^<>]*)([<>]*)/", $attr,$match);
 	  list(,$mattr,$mdir) = $match;
-	  #echo "<br>DBG \$mattr=$mattr,\$mdir=$mdir";
+	  #echo "<br />DBG \$mattr=$mattr,\$mdir=$mdir";
 	  if ($mattr == $order)
 	    {
 	      if ( ($mdir == '>') || (!isset($mdir)) )
@@ -1259,7 +1337,7 @@ function trackers_add_sort_criteria($criteria_list, $order, $msort)
 	}
     }
     
-  #echo "<br>DBG \$arr[]=".join(',',$arr);
+  #echo "<br />DBG \$arr[]=".join(',',$arr);
 
   return(join(',', $arr));	
 
@@ -1297,7 +1375,7 @@ function trackers_criteria_list_to_text($criteria_list, $url)
 	  $arr_text[] = '<a href="'.$url.'&amp;morder='.$morder.'#results">'.
 	     trackers_data_get_label($attr).'</a><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.
 	     ((substr($crit, -1) == '<') ? 'down' : 'up').
-	     '.png" border="0">';
+	     '.png" border="0" />';
 	}
     }
 
@@ -1312,14 +1390,14 @@ function trackers_build_match_expression($field, &$to_match)
   $res = db_query("SHOW COLUMNS FROM ".ARTIFACT." LIKE '$field'");
   $type = db_result($res,0,'Type');
 
-  #echo "<br>DBG '$field' field type = $type";
+  #echo "<br />DBG '$field' field type = $type";
 
   if (preg_match('/text|varchar|blob/i', $type))
     {
 
       # If it is sourrounded by /.../ the assume a regexp
       # else transform into a series of LIKE %word%
-      if (preg_match('/\/(.*)\#', $to_match, $matches))
+      if (preg_match('/\/(.*)\#/', $to_match, $matches))
 	$expr = "$field RLIKE '".$matches[1]."' ";
       else
 	{
@@ -1327,7 +1405,7 @@ function trackers_build_match_expression($field, &$to_match)
 	  reset($words);
 	  while ( list($i,$w) = each($words))
 	    {
-	      #echo "<br>DBG $i, $w, $words[$i]";
+	      #echo "<br />DBG $i, $w, $words[$i]";
 	      $words[$i] = "$field LIKE '%$w%'";
 	    }
 	  $expr = join(' AND ', $words);
@@ -1433,7 +1511,7 @@ function trackers_build_match_expression($field, &$to_match)
       $expr = "$field = '$to_match'";
     }
 
-  #echo "<br>DBG expr to match for '$field' = $expr";
+  #echo "<br />DBG expr to match for '$field' = $expr";
   return ' ('.$expr.') ';
 
 }
