@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: field_usage.php,v 1.19 2004/07/03 16:07:30 yeupou Exp $
+# $Id: field_usage.php,v 1.20 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
@@ -64,7 +64,7 @@ if ($group_id && (user_ismember($group_id,'B2') || user_ismember($group_id,'A'))
 
 	  trackers_data_update_usage($field,$group_id,$label,$description,
 				$status,$place,$display_size,$empty_ok,$keep_history,
-				$show_on_add_members,$show_on_add);
+				$show_on_add_members,$show_on_add, $form_transition_default_auth);
 	}
       else if ($reset)
 	{
@@ -85,40 +85,35 @@ if ($group_id && (user_ismember($group_id,'B2') || user_ismember($group_id,'A'))
 
       # Escape to display the form
 
-
-      #      print '<h2>'._("Modify a bug field").' '.help_button('bug_admin_field_usage_settings',false).'</h2>';
       print '<form action="'.$PHP_SELF.'" method="post">';
-      print '<input type="hidden" name="post_changes" value="y">
-      <input type="hidden" name="field" value="'.$field.'">
-      <input type="hidden" name="group_id" value="'.$group_id.'">
-      <p><h3>'
-	._("Field Label:");
+      print '<input type="hidden" name="post_changes" value="y" />
+      <input type="hidden" name="field" value="'.$field.'" />
+      <input type="hidden" name="group_id" value="'.$group_id.'" />
+      <h2>'
+	._("Field Label:").' ';
 
+      $closetag = ' &nbsp;&nbsp; <font class="smaller">['.utils_link($GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group='.$group_name.'&amp;list_value=1&amp;field='.$field, _("Jump to this field values"))."]</font></h2>\n";
 
       # If it is a custom field let the user change the label and description
       if (trackers_data_is_custom($field))
 	{
 	  print '<input type="text" name="label" value="'.trackers_data_get_label($field).
-	    '" size="20" maxlength="85"></h3>';
-	  print '<b>'._("Description:").' </b>';
+	    '" size="20" maxlength="85">'.$closetag;
+	  print '<span class="preinput">'._("Description:").' </span>';
 	  print '<input type="text" name="description" value="'.trackers_data_get_description($field).
-	    '" size="70" maxlength="255"><p>';
+	    '" size="70" maxlength="255" />';
 	}
       else
 	{
-	  print trackers_data_get_label($field)."</h3>\n";
+	  print trackers_data_get_label($field).$closetag;
 	}
 
-      print '<b>'._("Rank on screen").':</b>';
-
-      print '<input type="text" name="place" value="'.trackers_data_get_place($field).
-	'" size="6" maxlength="6">&nbsp;&nbsp;'."\n";
-      print '<b>'._("Status").':</b>';
+      print '<span class="preinput">'._("Status:").' </span>&nbsp;&nbsp;';
       # Display the Usage box (Used, Unused select box  or hardcoded "required')
       if (trackers_data_is_required($field))
 	{
 	  print _("Required");
-	  print '<input type="hidden" name="status" value="1">';
+	  print '<input type="hidden" name="status" value="1" />';
 	}
       else
 	{
@@ -132,24 +127,24 @@ if ($group_id && (user_ismember($group_id,'B2') || user_ismember($group_id,'A'))
       if (trackers_data_is_text_field($field))
 	{
 	  list($size,$maxlength) = trackers_data_get_display_size($field);
-	  print '<p><b>'._("Field Size...").'</b> ('._("in characters").')<ul>';
-	  print '<li>'._("Visible Field Size:").' ';
+	  print '<h3>'._("Field Size:").' ('._("in characters").')</h3><ul>';
+	  print '<li><span class="preinput">'._("Visible Field Size:").' </span>';
 	  print '<input type="text" name="n1" value="'.$size.
-	    '" size="3" maxlength="3">&nbsp;&nbsp;';
-	  print '<li>'._("Maximum length:").' ';
+	    '" size="3" maxlength="3" />&nbsp;&nbsp;';
+	  print '<li><span class="preinput">'._("Maximum length:").' </span>';
 	  print '<input type="text" name="n2" value="'.$maxlength.
-	    '" size="3" maxlength="3">&nbsp;&nbsp; (up to  255)</ul></p>';
+	    '" size="3" maxlength="3" />&nbsp;&nbsp; ('._("up to  255").'</ul>';
 	}
       else if (trackers_data_is_text_area($field))
 	{
 	  list($rows,$cols) = trackers_data_get_display_size($field);
-	  print '<p><b>'._("Field Size...").'</b><ul>';
-	  print '<li>'._("Number of rows:").' ';
+	  print '<h3>'._("Field Size:").'</h3><ul>';
+	  print '<li><span class="preinput">'._("Number of rows:").' </span>';
 	  print '<input type="text" name="n1" value="'.$rows.
-	    '" size="3" maxlength="3">&nbsp;&nbsp;';
-	  print '<li>'._("Number of columns:").' ';
+	    '" size="3" maxlength="3" />&nbsp;&nbsp;';
+	  print '<li><span class="preinput">'._("Number of columns:").' </span>';
 	  print '<input type="text" name="n2" value="'.$cols.
-	    '" size="3" maxlength="3"></ul></p>';
+	    '" size="3" maxlength="3" /></ul>';
 	}
       # Remark: Date fields have a fixed size that cannot be changed
 
@@ -157,17 +152,15 @@ if ($group_id && (user_ismember($group_id,'B2') || user_ismember($group_id,'A'))
       # Customize Properties
       if (!trackers_data_is_special($field))
 	{
-	  print '<p><b>'
-	    ._("Properties...").'</b><ul>';
-	  print '<li>'
-	    ._("Allow Empty Value:").' ';
-	  print '<input type="checkbox" name="empty_ok" value="1" '.
-	    (trackers_data_is_empty_ok($field)?' checked':'').'>&nbsp;&nbsp;';
-	  print '<input type="hidden" name="empty_ok_here" value="1">';
-	  print '<li>'._("Keep Change History:").' ';
-	  print '<input type="checkbox" name="keep_history" value="1" '.
-	    (trackers_data_do_keep_history($field)?' checked':'').'></ul></p>';
-	  print '<input type="hidden" name="keep_history_here" value="1">';
+	  print '<h3>'
+	    ._("Properties:").'</h3><ul>';
+	  print '<li><input type="checkbox" name="empty_ok" value="1" '.
+	    (trackers_data_is_empty_ok($field)?' checked="checked"':'').' /><input type="hidden" name="empty_ok_here" value="1" />'.
+	    ' <span class="preinput">' ._("Allow Empty Value").' </span></li>';
+	  print '<li><input type="checkbox" name="keep_history" value="1" '.
+	    (trackers_data_do_keep_history($field)?' checked="checked"':'').' /><input type="hidden" name="keep_history_here" value="1" />'.
+	    '  <span class="preinput">'._("Keep Change History").'</span></li>';
+	  print '</ul>';
 	}
 
       # Customize screen presence
@@ -175,13 +168,13 @@ if ($group_id && (user_ismember($group_id,'B2') || user_ismember($group_id,'A'))
 	  !trackers_data_is_special($field_name))
 	{
 
-	  $addm_html = '&nbsp;&nbsp;<input type="checkbox" name="show_on_add_members" value="1"'.
-	     (trackers_data_is_showed_on_add_members($field)?' checked':'').'>';
+	  $addm_html = '<input type="checkbox" name="show_on_add_members" value="1"'.
+	     (trackers_data_is_showed_on_add_members($field)?' checked="checked"':'').' />';
 
-	  $add_html = '&nbsp;&nbsp;<input type="checkbox" name="show_on_add" value="1"'.
-	     (trackers_data_is_showed_on_add($field)?' checked':'').'>';
-	  $add_nologin_html = '&nbsp;&nbsp;<input type="checkbox" name="show_on_add_nologin" value="2"'.
-	     (trackers_data_is_showed_on_add_nologin($field)?' checked':'').'>';
+	  $add_html = '<input type="checkbox" name="show_on_add" value="1"'.
+	     (trackers_data_is_showed_on_add($field)?' checked="checked"':'').' />';
+	  $add_nologin_html = '<input type="checkbox" name="show_on_add_nologin" value="2"'.
+	     (trackers_data_is_showed_on_add_nologin($field)?' checked="checked"':'').' />';
 
 	}
       else
@@ -191,31 +184,40 @@ if ($group_id && (user_ismember($group_id,'B2') || user_ismember($group_id,'A'))
 	  # form to preserve the existing setting or use the default values
 	  # imposed at the system level
 	  $addm_html = '<input type="hidden" name="show_on_add_members" '.
-	     'value="'.(trackers_data_is_showed_on_add_members($field)? 1:0).'">'.
+	     'value="'.(trackers_data_is_showed_on_add_members($field)? 1:0).'" />'.
 	     (trackers_data_is_showed_on_add_members($field)? ': '._("Always"):': '._("Never"));
 	  $add_html = '<input type="hidden" name="show_on_add" '.
-	     'value="'.(trackers_data_is_showed_on_add($field)? 1:0).'">'.
+	     'value="'.(trackers_data_is_showed_on_add($field)? 1:0).'" />'.
 	     (trackers_data_is_showed_on_add($field)? ': '._("Always").'':': '._("Never").'');
 	  
 	  $add_nologin_html = '<input type="hidden" name="show_on_add_nologin" '.
-	    'value="'.(trackers_data_is_showed_on_add_nologin($field)? 2:0).'">'.
+	    'value="'.(trackers_data_is_showed_on_add_nologin($field)? 2:0).'" />'.
 	    (trackers_data_is_showed_on_add_nologin($field)? ': '._("Always").'':': '._("Never").'');
 
 
 	}
 
-      print '<p><b>'._("Display this field...").'</b><ul>';
-      print '<li>'._("On the submission form used by project members").$addm_html.'</li>';
-      print '<li>'._("On the submission form used by other logged in users").$add_html.'</li>';
-      print '<li>'._("On the submission form used by non logged in users").$add_nologin_html.'</li>';
-      
+      print '<h3>'._("Display:").'</h3>';
+      print '<span class="preinput">'._("Rank on screen:").' </span>&nbsp;&nbsp;';
 
-      print '</ul></p>
-      	<p>
-      	<input type="submit" name="submit" value="'._("Submit").'">
-      	&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
+      print '<input type="text" name="place" value="'.trackers_data_get_place($field).
+	'" size="6" maxlength="6" />'."\n";
+      print '<ul>';
+      print '<li>'.$addm_html.' <span class="preinput">'._("On the submission form used by project members").'</span></li>';
+      print '<li>'.$add_html.' <span class="preinput">'._("On the submission form used by other logged in users").'</span></li>';
+      print '<li>'.$add_nologin_html.' <span class="preinput">'._("On the submission form used by non logged in users").'</span></li></ul>';
+      
+      $transition_default_auth = db_result(db_query("SELECT transition_default_auth FROM ".ARTIFACT."_field_usage WHERE group_id='$group_id' AND bug_field_id='".trackers_data_get_field_id($field)."'"), 0, 'transition_default_auth');
+
+      print '<h3>'._("By default, transitions (from one value to another) are:").'</h3><ul>';
+      print '<li><input type="radio" name="form_transition_default_auth" value="A" '.(($transition_default_auth!='F')?' checked="checked"':'').' /> '._("Allowed").'</li><li><input type="radio" name="form_transition_default_auth" value="F" '.(($transition_default_auth=='F')?'checked="checked"':'').' /> '._("Forbidden").'</li></ul>';
+
+      print '
+      	<p align="center">
+      	<input type="submit" name="submit" value="'._("Update").'" />
+      	&nbsp;&nbsp;
       	<input type="submit" name="reset" value="'
-	._("RESET TO DEFAULTS").'"></p>
+	._("Reset to defaults").'" /></p>
       	</form>';
 
 
@@ -232,7 +234,7 @@ if ($group_id && (user_ismember($group_id,'B2') || user_ismember($group_id,'A'))
 
       trackers_header_admin(array ('title'=>_("Field Usage")));
 
-      print '<h3>'._("List of all Available Fields").'</h3>';
+      print '<h2>'._("List of all Available Fields").'</h2>';
       print '<p>('._("Click to modify").')</p>';
 
 
