@@ -2,12 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: browse.php,v 1.29 2004/06/28 14:21:32 yeupou Exp $
+# $Id: browse.php,v 1.30 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#                          Yves Perrin <yves.perrin--at--cern.ch>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -59,11 +60,11 @@ while (list($field,$value_id) = each($prefs))
     {
       unset($prefs[$field]);
       $prefs[$field][] = $value_id;
-      #echo '<br> DBG Setting $prefs['.$field.'] [] = '.$value_id;
+      #print '<br /> DBG Setting $prefs['.$field.'] [] = '.$value_id;
     }
   else
     {
-      #echo '<br> DBG $prefs['.$field.'] = ('.implode(',',$value_id).')';
+      #print '<br /> DBG $prefs['.$field.'] = ('.implode(',',$value_id).')';
     }
 
   if (trackers_data_is_date_field($field))
@@ -72,7 +73,7 @@ while (list($field,$value_id) = each($prefs))
 	{
 	  $field_end = $field.'_end';
 	  $prefs[$field_end] = $$field_end;
-	  #echo '<br> DBG Setting $prefs['.$field.'_end]= '.$prefs[$field.'_end'];
+	  #print '<br /> DBG Setting $prefs['.$field.'_end]= '.$prefs[$field.'_end'];
 	}
       else
 	{
@@ -80,7 +81,7 @@ while (list($field,$value_id) = each($prefs))
 	  $prefs[$field_op] = $$field_op;
 	  if (!$prefs[$field_op])
 	    $prefs[$field_op] = '>';
-	  #echo '<br> DBG Setting $prefs['.$field.'_op]= '.$prefs[$field.'_op'];
+	  #print '<br /> DBG Setting $prefs['.$field.'_op]= '.$prefs[$field.'_op'];
 	}
     }
 }
@@ -94,7 +95,7 @@ while (list($field,$value_id) = each($prefs))
    $order = last sort criteria selected in the UI
    $msort = 1 if multicolumn sort activated.
   ================================================== */
-#echo "<br>DBG \$morder at top: [$morder ]";
+#print "<br />DBG \$morder at top: [$morder ]";
 #   if morder not defined then reuse the one in preferences
 if (user_isloggedin() && !isset($morder))
 {
@@ -131,7 +132,7 @@ if (isset($morder))
     }
 }
 
-#echo "<BR> DBG Order by = $order_by";
+#print "<BR> DBG Order by = $order_by";
 
 
 /* ==================================================
@@ -159,7 +160,6 @@ if (!$report_id)
 trackers_report_init($group_id, $report_id);
 
 
-
 /* ==================================================
   Now see what type of bug set is requested (set is one of none,
   'my', 'open', 'custom').
@@ -196,7 +196,7 @@ if (!$set)
 	      else
 		$prefs[$field][] = $value_id;
 
-	      #echo '<br>DBG restoring prefs : $prefs['.$field.'] []='.$value_id;
+	      #print '<br />DBG restoring prefs : $prefs['.$field.'] []='.$value_id;
 	    }
 	  $set='custom';
 
@@ -241,7 +241,7 @@ else if ($set=='custom')
       # Do not add the criteria in the header if value is "Any"
       if ($value_id != 0)
 	{
-	  $hdr .= ' By '.trackers_data_get_label($field).': '.
+	  $hdr .= _(" By ").trackers_data_get_label($field).': '.
 	     trackers_data_get_value($field,$group_id,$value_id);
 	}
     }
@@ -252,7 +252,7 @@ else if ($set=='custom')
 
   if ($pref_stg != user_get_preference('bug_brow_cust'.$group_id))
     {
-      #echo "<br> DBG setting pref = $pref_stg";
+      #print "<br /> DBG setting pref = $pref_stg";
       user_set_preference('bug_brow_cust'.$group_id,$pref_stg);
     }
 
@@ -291,7 +291,7 @@ while ($field = trackers_list_all_fields())
 # item title is provided to everybody.
 $col_list = $lbl_list = array();
 $select_count = 'SELECT count(*) AS count ';
-$select = 'SELECT '.ARTIFACT.'.priority,'.ARTIFACT.'.privacy  ';
+$select = 'SELECT '.ARTIFACT.'.priority,'.ARTIFACT.'.privacy,'.ARTIFACT.'.status_id';
 $from = 'FROM '.ARTIFACT.' ';
 $where = 'WHERE '.ARTIFACT.'.group_id='.$group_id.' ';
 if (!$pv)
@@ -315,49 +315,51 @@ while (list($field,$value_id) = each($prefs))
       # Only select box criteria to where clause if argument is not ANY
       $where .= ' AND '.ARTIFACT.'.'.$field.' IN ('.implode(',',$prefs[$field]).') ';
 
-    } else if (trackers_data_is_date_field($field) && $prefs[$field][0])
-      {
-
-	# transform a date field into a unix time and use <, > or =
-	list($time,$ok) = utils_date_to_unixtime($prefs[$field][0]);
-
-	if ($advsrch)
-	  {
-	    list($time_end,$ok_end) = utils_date_to_unixtime($prefs[$field.'_end'][0]);
-	    if ($ok)
-	      $where .= ' AND '.ARTIFACT.'.'.$field.' >= '. $time;
-
-	    if ($ok_end)
-	      $where .= ' AND '.ARTIFACT.'.'.$field.' <= '. $time_end;
-
-
-	  }
-	else
-	  {
-
-	    $operator = $prefs[$field.'_op'][0];
-	    # '=' means that day between 00:00 and 23:59
-	    if ($operator == '=')
-	      {
-		$time_end = mktime(23, 59, 59, $month, $day, $year);
-		$where .= ' AND '.ARTIFACT.'.'.$field." >= $time ".'AND '.ARTIFACT.'.'.$field." <= $time_end ";
-	      }
-	    else
-	      {
-		$where .= ' AND '.ARTIFACT.'.'.$field." $operator= $time ";
-	      }
-	  }
-
-	# Always exclude undefined dates (0)
-	$where .= ' AND '.ARTIFACT.'.'.$field." <> 0 ";
-
-      } else if ((trackers_data_is_text_field($field) || trackers_data_is_text_area($field))
-		 && $prefs[$field][0])
+    } 
+  else if (trackers_data_is_date_field($field) && $prefs[$field][0])
+    {
+      
+# transform a date field into a unix time and use <, > or =
+      list($time,$ok) = utils_date_to_unixtime($prefs[$field][0]);
+      
+      if ($advsrch)
 	{
-
-	  # It's a text field accept. Process INT or TEXT,VARCHAR fields differently
-	  $where .= ' AND '.trackers_build_match_expression($field, $prefs[$field][0]);
+	  list($time_end,$ok_end) = utils_date_to_unixtime($prefs[$field.'_end'][0]);
+	  if ($ok)
+	    { $where .= ' AND '.ARTIFACT.'.'.$field.' >= '. $time; }
+	  
+	  if ($ok_end)
+	    { $where .= ' AND '.ARTIFACT.'.'.$field.' <= '. $time_end; }
+	  
 	}
+      else
+	{
+	  
+	  $operator = $prefs[$field.'_op'][0];
+          # '=' means that day between 00:00 and 23:59
+	  if ($operator == '=')
+	    {
+	      $time_end = mktime(23, 59, 59, $month, $day, $year);
+	      $where .= ' AND '.ARTIFACT.'.'.$field." >= $time ".'AND '.ARTIFACT.'.'.$field." <= $time_end ";
+	    }
+	  else
+	    {
+	      $where .= ' AND '.ARTIFACT.'.'.$field." $operator= $time ";
+	    }
+	}
+      
+      # Always exclude undefined dates (0)
+      $where .= ' AND '.ARTIFACT.'.'.$field." <> 0 ";
+      
+    } 
+  elseif ((trackers_data_is_text_field($field) ||
+	    trackers_data_is_text_area($field)) && 
+	   $prefs[$field][0])
+    {
+    
+      # It s a text field accept. Process INT or TEXT,VARCHAR fields differently
+      $where .= ' AND '.trackers_build_match_expression($field, $prefs[$field][0]);
+    }
 }
 
 /* ==================================================
@@ -366,15 +368,13 @@ while (list($field,$value_id) = each($prefs))
   ================================================== */
 $ib=0;$is=0;
 $load_cal=false;
-while ( $field = trackers_list_all_fields(cmp_place_query))
+while ($field = trackers_list_all_fields(cmp_place_query))
 {
-
+  
   if (!trackers_data_is_used($field) ||
-      !trackers_data_is_showed_on_query($field) )
-    {
-      continue;
-    }
-
+      !trackers_data_is_showed_on_query($field))
+    { continue; }
+  
   # beginning of a new row
   if ($ib % $fields_per_line == 0)
     {
@@ -382,7 +382,7 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
       $labels .= "\n".'<tr align="'.$align.'" valign="top">';
       $boxes .= "\n".'<tr align="'.$align.'" valign="top">';
     }
-
+  
   $labels .= '<td class="preinput">'.trackers_data_get_label($field).' :</td>';
      # Duh, it never work with konqueror and many others browsers
      # and basically, if "category" is unclear, the name of the field
@@ -392,42 +392,48 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
 
   $boxes .= '<TD><FONT SIZE="-1">';
 
-  if (trackers_data_is_select_box($field) )
+  if (trackers_data_is_select_box($field))
     {
-
       $boxes .=
 	 trackers_field_display($field,$group_id,
 				($advsrch ? $prefs[$field] : $prefs[$field][0]),
 				false,false,($pv?true:false),false,true,'None', true,'Any');
-
-    } else if (trackers_data_is_date_field($field) ){
-
+      
+    } 
+  else if (trackers_data_is_date_field($field))
+    {
+      
       if ($advsrch)
-	$boxes .= trackers_multiple_field_date($field,$prefs[$field][0],
-					       $prefs[$field.'_end'][0],0,0,$pv);
+	{ 
+	  $boxes .= trackers_multiple_field_date($field,$prefs[$field][0],
+						 $prefs[$field.'_end'][0],0,0,$pv);
+	}
       else
-	$boxes .= trackers_field_date_operator($field,$prefs[$field.'_op'][0],$pv).
-	  trackers_field_date($field,$prefs[$field][0],0,0,$pv);
+	{
+	  $boxes .= trackers_field_date_operator($field,$prefs[$field.'_op'][0],$pv).
+	     trackers_field_date($field,$prefs[$field][0],0,0,$pv);
+	} 
+      
+    }
+  else if (trackers_data_is_text_field($field) ||trackers_data_is_text_area($field))
+    {
+# yeupou--gnu.org 2004-09-17: how can we reach this elseif after an
+# if?	  
+      $boxes .=
+	 ($pv ? $prefs[$field][0] : trackers_field_text($field,$prefs[$field][0],15,80)) ;
+    }
 
-    } else if (trackers_data_is_text_field($field) ||
-	       trackers_data_is_text_area($field) )
-      {
-
-	$boxes .=
-	   ($pv ? $prefs[$field][0] : trackers_field_text($field,$prefs[$field][0],15,80)) ;
-
-      }
   $boxes .= "</TD>\n";
-
+  
   $ib++;
-
-  # end of this row
+  
+# end of this row
   if ($ib % $fields_per_line == 0)
     {
       $html_select .= $labels.'</TR>'.$boxes.'</TR>';
       $labels = $boxes = '';
     }
-
+  
 }
 
 # Make sure the last few cells are in the table
@@ -445,22 +451,21 @@ while ( $field = trackers_list_all_fields(cmp_place_result))
 {
 
   if (!trackers_data_is_used($field) ||
-      !trackers_data_is_showed_on_result($field) )
-    {
-      continue;
-    }
+      !trackers_data_is_showed_on_result($field))
+    { continue; }
 
   $col_list[] = $field;
   $width_list[] = trackers_data_get_col_width($field);
   $lbl_list[] = trackers_data_get_label($field);
-
-  if ( trackers_data_is_username_field($field))
+  
+  if (trackers_data_is_username_field($field))
     {
       # user names requires some special processing to display the username
       # instead of the user_id
       $select .= ",user_$field.user_name AS $field";
       $from .= ",user user_$field";
       $where .= " AND user_$field.user_id=".ARTIFACT.".$field ";
+      #dbg("ICI $field ");
     }
   else
     {
@@ -484,7 +489,7 @@ $totalrows = db_result($result_count,0,'count');
 
 $sql = "$select $from $where $order_by $limit";
 $result=db_query($sql);
-#echo "<br> DBG SQL = $sql";
+#dbg("SQL = $sql");
 #exit 0;
 
 
@@ -494,14 +499,14 @@ $result=db_query($sql);
 
 if ($pv)
 {
-  help_header(_("Bug Search Report").' - '.format_date($sys_datefmt,time()),false);
+  help_header(_("Item Search Report").' - '.format_date($sys_datefmt,time()),false);
 }
 else
 {
   trackers_header(array('title'=>_("Browse").' '.$hdr));
 }
 
-echo '    <FORM ACTION="'.$PHP_SELF .'" METHOD="GET" NAME="bug_form">
+print '    <FORM ACTION="'.$PHP_SELF .'" METHOD="GET" NAME="bug_form">
           <INPUT TYPE="HIDDEN" NAME="group_id" VALUE="'.$group_id.'">
           <INPUT TYPE="HIDDEN" NAME="set" VALUE="custom">
           <INPUT TYPE="HIDDEN" NAME="msort" VALUE="'.$msort.'">
@@ -517,14 +522,14 @@ if (!$pv)
 }
 
 # Start building the URL that we use to for hyperlink in the form
-$url = $GLOBALS['sys_home'].ARTIFACT."/?group_id=$group_id&func=browse&set=$set&msort=$msort";
+$url = $GLOBALS['sys_home'].ARTIFACT."/?group=$group_name&amp;func=browse&amp;set=$set&amp;msort=$msort";
 if ($set == 'custom')
      $url .= $pref_stg;
      else
-     $url .= '&advsrch='.$advsrch;
+     $url .= '&amp;advsrch='.$advsrch;
 
 $url_nomorder = $url;
-$url .= "&morder=$morder";
+$url .= "&amp;morder=$morder";
 
 # Build the URL for alternate Search
 if ($advsrch)
@@ -543,28 +548,28 @@ if (!$pv)
 {
   if ($advsrch)
     {
-      $advsrch_1 = ' selected';
+      $advsrch_1 = ' selected="selected"';
     }
   else
     {
-      $advsrch_0 = ' selected';
+      $advsrch_0 = ' selected="selected"';
     }
   printf(' '._("and %s selection."), '<select name="advsrch"><option value="0"'.$advsrch_0.'>'._("Simple").'</option><option value="1"'.$advsrch_1.'>'._("Multiple").'</option></select>');
 }
 
 # End the form type selection
-echo '<input value="'._("Apply").'" name="go_report" type="submit">';
-echo '</h3>';
+print '<input value="'._("Apply").'" name="go_report" type="submit">';
+print '</h3>';
 
-echo '<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="5">
+print '<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="5">
         <TR><TD colspan="'.$fields_per_line.'" nowrap>';
 
-echo $html_select;
+print $html_select;
 
-echo '</table>';
+print '</table>';
 if (!$pv)
 {
-  echo '<p><font class="smaller">Show</font> '.
+  print '<p><font class="smaller">Show</font> '.
     '<input type="text" name="chunksz" size="3" maxlength="5" '.
     'value="'.$chunksz.'"> '._("items at once").'.</form>';
 }
@@ -587,20 +592,20 @@ if ($result && $numrows > 0)
     {
       $order_statement ='';
     }
-  echo '<a name="results"></a>';
+  print '<a name="results"></a>';
   # add the plural in brackets, so it looks a little nicer -- toddy 2004-02-29
-  echo '<h3>'.$totalrows.' '._("matching item(s)").' '.$order_statement.'</h3>';
+  print '<h3>'.$totalrows.' '._("matching item(s)").' '.$order_statement.'</h3>';
 
 
   if (!$pv)
     {
-    echo '<p>';
+    print '<p>';
     if ($msort)
       {
-        $url_alternate_sort = str_replace('msort=1','msort=0',$url).'&order=#results';
+        $url_alternate_sort = str_replace('msort=1','msort=0',$url).'&amp;order=#results';
         printf(_("Click a column heading to sort results (up or down), or %ssort by priority%s or %sreset sort%s. You can also %sdeactivate%s multicolumn sort."),
           '<a href="'.$url.'&amp;order=priority#results"><b>', '</b></a>',
-          '<a href="'.$url.'&order=#results"><b>', '</b></a>',
+          '<a href="'.$url.'&amp;order=#results"><b>', '</b></a>',
           '<a href="'.$url_alternate_sort.'"><b>', '</b></a>');
       }
     else
@@ -608,11 +613,11 @@ if ($result && $numrows > 0)
         $url_alternate_sort = str_replace('msort=0','msort=1',$url).'&order=#results';
         printf(_("Click a column heading to sort results (up or down), or %ssort by priority%s or %sreset sort%s. You can also %sactivate%s multicolumn sort."),
           '<a href="'.$url.'&amp;order=priority#results"><b>', '</b></a>',
-          '<a href="'.$url.'&order=#results"><b>', '</b></a>',
+          '<a href="'.$url.'&amp;order=#results"><b>', '</b></a>',
           '<a href="'.$url_alternate_sort.'"><b>', '</b></a>');
       }
-      echo '&nbsp;&nbsp;&nbsp;&nbsp;(<a href="'.$url.'&pv=1"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/print.png" border="0">';
-      echo '&nbsp;'._("Printer version").'</a>)</p>'."\n";
+      print '&nbsp;&nbsp;&nbsp;&nbsp;(<a href="'.$url.'&pv=1"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/print.png" border="0" />';
+      print '&nbsp;'._("Printer version").'</a>)</p>'."\n";
     }
   else
     {
@@ -626,14 +631,14 @@ if ($result && $numrows > 0)
 else
 {
 
-  echo '<h2>'._("No Matching Items Found for").' '.group_getname($group_id).' '._("or filters too restrictive").'</h2>';
-  echo db_error();
+  print '<h2>'.sprintf(_("No Matching Items Found for %s or filters too restrictive"), group_getname($group_id)).'</h2>';
+  print db_error();
 
 }
 
 if ($pv)
-     help_footer();
-     else
-     trackers_footer(array());
+{ help_footer(); }
+else
+{ trackers_footer(array()); }
 
 ?>
