@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: createjob.php,v 1.18 2004/06/26 08:02:16 yeupou Exp $
+# $Id: createjob.php,v 1.19 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -51,17 +51,17 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
 		<form action="'.$GLOBALS['sys_home'].'people/editjob.php" method="POST">
 		<input type="HIDDEN" name="group_id" value="'.$group_id.'">
 		<b>'
-    ._("Category:").'</b><br>'
+    ._("Category:").'</b><br />'
     . people_job_category_box('category_id') .'
 		<p>
 		<b>'
-    ._("Summary").':</b><br>
+    ._("Summary").':</b><br />
 		<input type="text" name="title" value="" size="40" maxlength="60">
 		<p>'
     ._("Your project description will be inserted on the announce.").'
         <p>
 		<b>'
-    ._("Details (job description, contact...):").'</b><br>
+    ._("Details (job description, contact...):").'</b><br />
 		<textarea name="description" rows="10" cols="60" wrap="soft"></textarea>
 		<p>
 		<input type="submit" name="add_job" value="'
