@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: viewprofile.php,v 1.16 2004/03/13 18:22:06 yeupou Exp $
+# $Id: viewprofile.php,v 1.17 2004/09/22 08:11:52 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) ...
+#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,58 +23,47 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+# FIXME: this page is not a profile but a resume page.
 
 require "../include/pre.php";
 
 if ($user_id) 
 {
+  site_header(array('title'=>_("User Resume"),'toptab'=>'people'));
 
-  /*
-		Fill in the info to create a job
-  */
-  echo $HTML->header(array('title'=>_("User Skills/Resume")));
-
-  #for security, include group_id
+  #for security, include user_id
   $sql="SELECT * FROM user WHERE user_id='$user_id'";
   $result=db_query($sql);
 
-  if (!$result )
+  if (!$result || (db_numrows($result) < 1))
     {
-      fb(_("User fetch FAILED").' : '.db_error());
-
-    } 
-  else if (db_numrows($result) < 1) 
-    {
-      fb(_("User unknown").' !');
+      fb(_("User not found"),1);
 
     } 
   else if (db_result($result,0,'people_view_skills') != 1) 
     {
-      #	profile set private
-      fb(_("This user has set his/her profile to private"));
-
+      fb(_("This user has set his/her profile to private"),1);
     } 
   else 
     {
-      echo '<h2>'.sprintf('%s\'s Skills and Resume',db_result($result,0,'user_name')) .'</h2>';
-
       # we get site-specific content
       utils_get_content("people/viewprofile");
 
-      echo '<h5>'._("Real Name:").'</h5>'. db_result($result,0,'realname') ;
-      echo '<h5>'._("Resume:").'</h5>'. utils_make_links(nl2br(db_result($result,0,'people_resume'))) ;
-      echo '<h5>'._("Skill inventory:").'</h5>';
-
-      echo people_show_skill_inventory($user_id);
+      print '<h3>'.sprintf(_("Resume of %s"),utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname'))).'</h3>';
+      print utils_make_links(nl2br(db_result($result,0,'people_resume'))) ;
+      
+      print '<br /><br />';
+      print '<h3>'.sprintf(_("Skills of %s"),utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname'))).'</h3>';
+      print people_show_skill_inventory($user_id);
     }
 
-  echo $HTML->footer(array());
+  print $HTML->footer(array());
 
 }
 else 
 {
   # user_id not defined :
-  exit_error(_("Error"),_("user_id not found."));
+  exit_missing_param();
 }
 
 ?>
