@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: memberlist.php,v 1.22 2004/06/26 08:02:16 yeupou Exp $
+# $Id: memberlist.php,v 1.23 2004/09/22 08:11:52 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -60,19 +60,19 @@ if ((!$group_id) && $form_grp)
 printf (_("Browse with the %s memberlist."), '<select name="detailed"><option value="0">'._("Basic").'</option><option value="1"'.$checked.'>'._("Detailed").'</option></select>');
 print '&nbsp;&nbsp;&nbsp;&nbsp;<input type="submit" value="'._("Apply").'"></h3></form>';
 
-print '<br>';
+print '<br />';
 
 
 if (!member_check(0,$group_id))
 {
   printf(_("If you would like to contribute to this project by becoming a member, %s, designated in bold text below."),
 	 '<a href="'.$GLOBALS['sys_home'].'my/groups.php?words='.group_getname($group_id).'#searchgroup">'._("contact one of the project admins")."</a>");
-  print '<br><br>';
+  print '<br /><br />';
 }
 else
 {
   print _("Note that you can 'watch' a member of your project. It allows you, for instance, to be the backup of someone when he's away from the office, to do the QA to all of his activities on this project: you will receive a copy of his mail notifications related to this project.");
-  print '<br><br>';
+  print '<br /><br />';
 
 }
 
@@ -141,9 +141,9 @@ $res_memb = db_query($sql);
 function specific_print_role ($row, $title)
 {
   print
-    (($row == 1)?$title.' '._("technician").',<br>':"").
-    (($row == 3)?$title.' '._("manager").',<br>':"").
-    (($row == 2)?$title.' '._("techn. & manager").',<br>':"");
+    (($row == 1)?$title.' '._("technician").',<br />':"").
+    (($row == 3)?$title.' '._("manager").',<br />':"").
+    (($row == 2)?$title.' '._("techn. & manager").',<br />':"");
 }
 
 $i = 1;
